@@ -1,9 +1,13 @@
-#include <SFML/System.hpp>
-#include <SFML/Window.hpp>
 #include <SFML/Graphics.hpp>
+
 #include <SFML/Audio.hpp>
+
 #include <SFML/Network.hpp>
 
+#include <SFML/Window.hpp>
+
+#include <SFML/System.hpp>
+
 // Do we want to showcase direct JNI/NDK interaction?
 // Undefine this to get real cross-platform code.
 // Uncomment this to try JNI access; this seems to be broken in latest NDKs
@@ -11,8 +15,8 @@
 
 #if defined(USE_JNI)
 // These headers are only needed for direct NDK/JDK interaction
-#include <jni.h>
 #include <android/native_activity.h>
+#include <jni.h>
 
 // Since we want to get the native activity from SFML, we'll have to use an
 // extra header here:
@@ -22,41 +26,41 @@
 int vibrate(sf::Time duration)
 {
     // First we'll need the native activity handle
-    ANativeActivity *activity = sf::getNativeActivity();
-    
+    ANativeActivity* activity = sf::getNativeActivity();
+
     // Retrieve the JVM and JNI environment
-    JavaVM* vm = activity->vm;
+    JavaVM* vm  = activity->vm;
     JNIEnv* env = activity->env;
 
     // First, attach this thread to the main thread
     JavaVMAttachArgs attachargs;
     attachargs.version = JNI_VERSION_1_6;
-    attachargs.name = "NativeThread";
-    attachargs.group = NULL;
-    jint res = vm->AttachCurrentThread(&env, &attachargs);
+    attachargs.name    = "NativeThread";
+    attachargs.group   = nullptr;
+    jint res           = vm->AttachCurrentThread(&env, &attachargs);
 
     if (res == JNI_ERR)
         return EXIT_FAILURE;
 
     // Retrieve class information
-    jclass natact = env->FindClass("android/app/NativeActivity");
+    jclass natact  = env->FindClass("android/app/NativeActivity");
     jclass context = env->FindClass("android/content/Context");
-    
+
     // Get the value of a constant
-    jfieldID fid = env->GetStaticFieldID(context, "VIBRATOR_SERVICE", "Ljava/lang/String;");
-    jobject svcstr = env->GetStaticObjectField(context, fid);
-    
+    jfieldID fid    = env->GetStaticFieldID(context, "VIBRATOR_SERVICE", "Ljava/lang/String;");
+    jobject  svcstr = env->GetStaticObjectField(context, fid);
+
     // Get the method 'getSystemService' and call it
-    jmethodID getss = env->GetMethodID(natact, "getSystemService", "(Ljava/lang/String;)Ljava/lang/Object;");
-    jobject vib_obj = env->CallObjectMethod(activity->clazz, getss, svcstr);
-    
+    jmethodID getss   = env->GetMethodID(natact, "getSystemService", "(Ljava/lang/String;)Ljava/lang/Object;");
+    jobject   vib_obj = env->CallObjectMethod(activity->clazz, getss, svcstr);
+
     // Get the object's class and retrieve the member name
-    jclass vib_cls = env->GetObjectClass(vib_obj);
-    jmethodID vibrate = env->GetMethodID(vib_cls, "vibrate", "(J)V"); 
-    
+    jclass    vib_cls = env->GetObjectClass(vib_obj);
+    jmethodID vibrate = env->GetMethodID(vib_cls, "vibrate", "(J)V");
+
     // Determine the timeframe
     jlong length = duration.asMilliseconds();
-    
+
     // Bzzz!
     env->CallVoidMethod(vib_obj, vibrate, length);
 
@@ -66,7 +70,7 @@ int vibrate(sf::Time duration)
     env->DeleteLocalRef(svcstr);
     env->DeleteLocalRef(context);
     env->DeleteLocalRef(natact);
-    
+
     // Detach thread again
     vm->DetachCurrentThread();
 }
@@ -75,28 +79,24 @@ int vibrate(sf::Time duration)
 // This is the actual Android example. You don't have to write any platform
 // specific code, unless you want to use things not directly exposed.
 // ('vibrate()' in this example; undefine 'USE_JNI' above to disable it)
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
     sf::VideoMode screen(sf::VideoMode::getDesktopMode());
 
     sf::RenderWindow window(screen, "");
     window.setFramerateLimit(30);
 
-    sf::Texture texture;
-    if(!texture.loadFromFile("image.png"))
-        return EXIT_FAILURE;
+    const sf::Texture texture("image.png");
 
     sf::Sprite image(texture);
-    image.setPosition(screen.width / 2, screen.height / 2);
-    image.setOrigin(texture.getSize().x/2, texture.getSize().y/2);
+    image.setPosition(sf::Vector2f(screen.size) / 2.f);
+    image.setOrigin(sf::Vector2f(texture.getSize()) / 2.f);
 
-    sf::Font font;
-    if (!font.loadFromFile("tuffy.ttf"))
-        return EXIT_FAILURE;
+    const sf::Font font("tuffy.ttf");
 
-    sf::Text text("Tap anywhere to move the logo.", font, 64);
+    sf::Text text(font, "Tap anywhere to move the logo.", 64);
     text.setFillColor(sf::Color::Black);
-    text.setPosition(10, 10);
+    text.setPosition({10, 10});
 
     sf::View view = window.getDefaultView();
 
@@ -109,48 +109,49 @@ int main(int argc, char *argv[])
 
     while (window.isOpen())
     {
-        sf::Event event;
-
-        while (active ? window.pollEvent(event) : window.waitEvent(event))
+        while (const std::optional event = active ? window.pollEvent() : window.waitEvent())
         {
-            switch (event.type)
+            if (event->is<sf::Event::Closed>() ||
+                (event->is<sf::Event::KeyPressed>() &&
+                 event->getIf<sf::Event::KeyPressed>()->code == sf::Keyboard::Key::Escape))
             {
-                case sf::Event::Closed:
-                    window.close();
-                    break;
-                case sf::Event::KeyPressed:
-                    if (event.key.code == sf::Keyboard::Escape)
-                        window.close();
-                    break;
-                case sf::Event::Resized:
-                    view.setSize(event.size.width, event.size.height);
-                    view.setCenter(event.size.width/2, event.size.height/2);
-                    window.setView(view);
-                    break;
-                case sf::Event::LostFocus:
-                    background = sf::Color::Black;
-                    break;
-                case sf::Event::GainedFocus:
-                    background = sf::Color::White;
-                    break;
-                
-                // On Android MouseLeft/MouseEntered are (for now) triggered,
-                // whenever the app loses or gains focus.
-                case sf::Event::MouseLeft:
-                    active = false;
-                    break;
-                case sf::Event::MouseEntered:
-                    active = true;
-                    break;
-                case sf::Event::TouchBegan:
-                    if (event.touch.finger == 0)
-                    {
-                        image.setPosition(event.touch.x, event.touch.y);
+                window.close();
+            }
+
+            else if (const auto* resized = event->getIf<sf::Event::Resized>())
+            {
+                const auto size = sf::Vector2f(resized->size);
+                view.setSize(size);
+                view.setCenter(size / 2.f);
+                window.setView(view);
+            }
+            else if (event->is<sf::Event::FocusLost>())
+            {
+                background = sf::Color::Black;
+            }
+            else if (event->is<sf::Event::FocusGained>())
+            {
+                background = sf::Color::White;
+            }
+            // On Android MouseLeft/MouseEntered are (for now) triggered,
+            // whenever the app loses or gains focus.
+            else if (event->is<sf::Event::MouseLeft>())
+            {
+                active = false;
+            }
+            else if (event->is<sf::Event::MouseEntered>())
+            {
+                active = true;
+            }
+            else if (const auto* touchBegan = event->getIf<sf::Event::TouchBegan>())
+            {
+                if (touchBegan->finger == 0)
+                {
+                    image.setPosition(sf::Vector2f(touchBegan->position));
 #if defined(USE_JNI)
-                        vibrate(sf::milliseconds(10));
+                    vibrate(sf::milliseconds(10));
 #endif
-                    }
-                    break;
+                }
             }
         }
 
@@ -161,7 +162,8 @@ int main(int argc, char *argv[])
             window.draw(text);
             window.display();
         }
-        else {
+        else
+        {
             sf::sleep(sf::milliseconds(100));
         }
     }
