@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Marco Antognini (antognini.marco@gmail.com),
+// Copyright (C) 2007-2025 Marco Antognini (antognini.marco@gmail.com),
 //                         Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
@@ -24,69 +24,51 @@
 ////////////////////////////////////////////////////////////
 
 #import "CocoaAppDelegate.h"
+
 #import "NSString+stdstring.h"
 
-// These define are used for converting the color of the NSPopUpButton
-#define BLUE    @"Blue"
-#define GREEN   @"Green"
-#define RED     @"Red"
+#include <filesystem>
 
-#if defined(__APPLE__)
-    #if defined(__clang__)
-        #pragma clang diagnostic ignored "-Wdeprecated-declarations"
-    #elif defined(__GNUC__)
-        #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-    #endif
-#endif
+// These define are used for converting the color of the NSPopUpButton
+#define BLUE  @"Blue"
+#define GREEN @"Green"
+#define RED   @"Red"
+
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
 // Our PIMPL
 struct SFMLmainWindow
 {
-    SFMLmainWindow(sf::WindowHandle win) :
-    renderWindow(win),
-    background(sf::Color::Blue)
+    SFMLmainWindow(sf::WindowHandle win) : renderWindow(win)
     {
-        std::string resPath = [[[NSBundle mainBundle] resourcePath] tostdstring];
-        if (!logo.loadFromFile(resPath + "/logo.png"))
-            NSLog(@"Couldn't load the logo image");
-
         logo.setSmooth(true);
 
-        sprite.setTexture(logo, true);
-        sf::FloatRect rect = sprite.getLocalBounds();
-        sf::Vector2f size(rect.width, rect.height);
-        sprite.setOrigin(size / 2.f);
-        sprite.scale(0.3f, 0.3f);
-
-        unsigned int ww = renderWindow.getSize().x;
-        unsigned int wh = renderWindow.getSize().y;
-        sprite.setPosition(sf::Vector2f(ww, wh) / 2.f);
-
-        if (!font.loadFromFile(resPath + "/tuffy.ttf"))
-            NSLog(@"Couldn't load the font");
+        sprite.setOrigin(sprite.getLocalBounds().getCenter());
+        sprite.scale({0.3f, 0.3f});
+        sprite.setPosition(sf::Vector2f(renderWindow.getSize()) / 2.f);
 
         text.setFillColor(sf::Color::White);
-        text.setFont(font);
     }
 
-    sf::RenderWindow    renderWindow;
-    sf::Font            font;
-    sf::Text            text;
-    sf::Texture         logo;
-    sf::Sprite          sprite;
-    sf::Color           background;
+    std::filesystem::path resPath{[[[NSBundle mainBundle] resourcePath] tostdstring]};
+    sf::RenderWindow      renderWindow;
+    sf::Font              font{resPath / "tuffy.ttf"};
+    sf::Text              text{font};
+    sf::Texture           logo{resPath / "logo.png"};
+    sf::Sprite            sprite{logo};
+    sf::Color             background{sf::Color::Blue};
 };
 
 // Private stuff
 @interface CocoaAppDelegate ()
 
-@property (assign) SFMLmainWindow*  mainWindow;
-@property (retain) NSTimer*         renderTimer;
-@property (assign) BOOL             visible;
+@property (assign) SFMLmainWindow* mainWindow;
+@property (retain) NSTimer*        renderTimer;
+@property (assign) BOOL            visible;
 
-@property (assign) BOOL             initialized;
+@property (assign) BOOL initialized;
 
--(void)renderMainWindow:(NSTimer*)aTimer;
+- (void)renderMainWindow:(NSTimer*)aTimer;
 
 @end
 
@@ -94,15 +76,15 @@ struct SFMLmainWindow
 // Finally, the implementation
 @implementation CocoaAppDelegate
 
-@synthesize window          = m_window;
-@synthesize sfmlView        = m_sfmlView;
-@synthesize textField       = m_textField;
+@synthesize window    = m_window;
+@synthesize sfmlView  = m_sfmlView;
+@synthesize textField = m_textField;
 
-@synthesize mainWindow      = m_mainWindow;
-@synthesize renderTimer     = m_renderTimer;
-@synthesize visible         = m_visible;
+@synthesize mainWindow  = m_mainWindow;
+@synthesize renderTimer = m_renderTimer;
+@synthesize visible     = m_visible;
 
-@synthesize initialized     = m_initialized;
+@synthesize initialized = m_initialized;
 
 - (id)init
 {
@@ -113,7 +95,7 @@ struct SFMLmainWindow
     return self;
 }
 
--(void)applicationDidFinishLaunching:(NSNotification*)aNotification
+- (void)applicationDidFinishLaunching:(NSNotification*)aNotification
 {
     (void)aNotification;
 
@@ -125,21 +107,20 @@ struct SFMLmainWindow
         self.visible = YES;
 
         // Launch the timer to periodically display our stuff into the Cocoa view.
-        self.renderTimer = [NSTimer timerWithTimeInterval:1.0/60.0
-                                                   target:self
-                                                 selector:@selector(renderMainWindow:)
-                                                 userInfo:nil
-                                                  repeats:YES];
-        [[NSRunLoop mainRunLoop] addTimer:self.renderTimer
-                                  forMode:NSDefaultRunLoopMode];
-        [[NSRunLoop mainRunLoop] addTimer:self.renderTimer
-                                  forMode:NSEventTrackingRunLoopMode];
+        self.renderTimer = [NSTimer
+            timerWithTimeInterval:1.0 / 60.0
+                           target:self
+                         selector:@selector(renderMainWindow:)
+                         userInfo:nil
+                          repeats:YES];
+        [[NSRunLoop mainRunLoop] addTimer:self.renderTimer forMode:NSDefaultRunLoopMode];
+        [[NSRunLoop mainRunLoop] addTimer:self.renderTimer forMode:NSEventTrackingRunLoopMode];
         /*
          * This is really some ugly code but in order to have the timer fired
          * periodically we need to add it to the two above runloop mode.
          *
          * The default mode allows timer firing while the user doesn't do anything
-         * while the second mode allows timer firing while he is using a slider
+         * while the second mode allows timer firing while they are using a slider
          * or a menu.
          */
 
@@ -147,33 +128,33 @@ struct SFMLmainWindow
     }
 }
 
--(void)dealloc
+- (void)dealloc
 {
     [self.renderTimer invalidate];
     self.mainWindow->renderWindow.close();
 
-    self.window             = nil;
-    self.sfmlView           = nil;
-    self.textField          = nil;
+    self.window    = nil;
+    self.sfmlView  = nil;
+    self.textField = nil;
 
     delete static_cast<SFMLmainWindow*>(self.mainWindow);
-    self.mainWindow         = 0;
-    self.renderTimer        = nil;
+    self.mainWindow  = nil;
+    self.renderTimer = nil;
 
     [super dealloc];
 }
 
--(void)renderMainWindow:(NSTimer*)aTimer
+- (void)renderMainWindow:(NSTimer*)aTimer
 {
     (void)aTimer;
 
     // Scaling
     /* /!\ we do this at 60fps so choose low scaling factor! /!\ */
-    if (sf::Keyboard::isKeyPressed(sf::Keyboard::Up))
-        self.mainWindow->sprite.scale(1.01f, 1.01f);
+    if (sf::Keyboard::isKeyPressed(sf::Keyboard::Key::Up))
+        self.mainWindow->sprite.scale({1.01f, 1.01f});
 
-    if (sf::Keyboard::isKeyPressed(sf::Keyboard::Down))
-        self.mainWindow->sprite.scale(0.99f, 0.99f);
+    if (sf::Keyboard::isKeyPressed(sf::Keyboard::Key::Down))
+        self.mainWindow->sprite.scale({0.99f, 0.99f});
 
     // Clear the window, display some stuff and display it into our view.
 
@@ -187,7 +168,7 @@ struct SFMLmainWindow
     self.mainWindow->renderWindow.display();
 }
 
--(IBAction)colorChanged:(NSPopUpButton*)sender
+- (IBAction)colorChanged:(NSPopUpButton*)sender
 {
     if (self.initialized)
     {
@@ -202,22 +183,22 @@ struct SFMLmainWindow
     }
 }
 
--(IBAction)rotationChanged:(NSSlider*)sender
+- (IBAction)rotationChanged:(NSSlider*)sender
 {
     if (self.initialized)
     {
         float angle = [sender floatValue];
-        self.mainWindow->sprite.setRotation(angle);
+        self.mainWindow->sprite.setRotation(sf::degrees(angle));
     }
 }
 
--(IBAction)visibleChanged:(NSButton*)sender
+- (IBAction)visibleChanged:(NSButton*)sender
 {
     if (self.initialized)
         self.visible = [sender state] == NSOnState;
 }
 
--(IBAction)textChanged:(NSTextField*)sender
+- (IBAction)textChanged:(NSTextField*)sender
 {
     if (self.initialized)
         self.mainWindow->text.setString([[sender stringValue] tostdwstring]);
@@ -235,7 +216,7 @@ struct SFMLmainWindow
 
 @implementation SilentWindow
 
--(void)keyDown:(NSEvent*)theEvent
+- (void)keyDown:(NSEvent*)theEvent
 {
     (void)theEvent;
     // Do nothing except preventing this alert.
