@@ -1,14 +1,21 @@
-
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
+#include "Client.hpp"
+
 #include <SFML/Audio.hpp>
+
 #include <SFML/Network.hpp>
+
 #include <iostream>
+#include <optional>
+
+#include <cstddef>
+#include <cstdint>
 
 
-const sf::Uint8 clientAudioData   = 1;
-const sf::Uint8 clientEndOfStream = 2;
+constexpr std::uint8_t clientAudioData   = 1;
+constexpr std::uint8_t clientEndOfStream = 2;
 
 
 ////////////////////////////////////////////////////////////
@@ -18,7 +25,6 @@ const sf::Uint8 clientEndOfStream = 2;
 class NetworkRecorder : public sf::SoundRecorder
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// Constructor
     ///
@@ -26,9 +32,7 @@ public:
     /// \param port Port of the remote host
     ///
     ////////////////////////////////////////////////////////////
-    NetworkRecorder(const sf::IpAddress& host, unsigned short port) :
-    m_host(host),
-    m_port(port)
+    NetworkRecorder(sf::IpAddress host, unsigned short port) : m_host(host), m_port(port)
     {
     }
 
@@ -38,56 +42,57 @@ public:
     /// \see SoundRecorder::~SoundRecorder()
     ///
     ////////////////////////////////////////////////////////////
-    ~NetworkRecorder()
+    ~NetworkRecorder() override
     {
         // Make sure to stop the recording thread
         stop();
     }
 
 private:
-
     ////////////////////////////////////////////////////////////
     /// \see SoundRecorder::onStart
     ///
     ////////////////////////////////////////////////////////////
-    virtual bool onStart()
+    bool onStart() override
     {
-        if (m_socket.connect(m_host, m_port) == sf::Socket::Done)
+        if (m_socket.connect(m_host, m_port) == sf::Socket::Status::Done)
         {
             std::cout << "Connected to server " << m_host << std::endl;
             return true;
         }
-        else
-        {
-            return false;
-        }
+
+        return false;
     }
 
     ////////////////////////////////////////////////////////////
     /// \see SoundRecorder::onProcessSamples
     ///
     ////////////////////////////////////////////////////////////
-    virtual bool onProcessSamples(const sf::Int16* samples, std::size_t sampleCount)
+    bool onProcessSamples(const std::int16_t* samples, std::size_t sampleCount) override
     {
         // Pack the audio samples into a network packet
         sf::Packet packet;
         packet << clientAudioData;
-        packet.append(samples, sampleCount * sizeof(sf::Int16));
+        packet.append(samples, sampleCount * sizeof(std::int16_t));
 
         // Send the audio packet to the server
-        return m_socket.send(packet) == sf::Socket::Done;
+        return m_socket.send(packet) == sf::Socket::Status::Done;
     }
 
     ////////////////////////////////////////////////////////////
     /// \see SoundRecorder::onStop
     ///
     ////////////////////////////////////////////////////////////
-    virtual void onStop()
+    void onStop() override
     {
-        // Send a "end-of-stream" packet
+        // Send an "end-of-stream" packet
         sf::Packet packet;
         packet << clientEndOfStream;
-        m_socket.send(packet);
+
+        if (m_socket.send(packet) != sf::Socket::Status::Done)
+        {
+            std::cerr << "Failed to send end-of-stream packet" << std::endl;
+        }
 
         // Close the socket
         m_socket.disconnect();
@@ -104,7 +109,7 @@ private:
 
 ////////////////////////////////////////////////////////////
 /// Create a client, connect it to a running server and
-/// start sending him audio data
+/// start sending it audio data
 ///
 ////////////////////////////////////////////////////////////
 void doClient(unsigned short port)
@@ -117,16 +122,15 @@ void doClient(unsigned short port)
     }
 
     // Ask for server address
-    sf::IpAddress server;
+    std::optional<sf::IpAddress> server;
     do
     {
         std::cout << "Type address or name of the server to connect to: ";
-        std::cin  >> server;
-    }
-    while (server == sf::IpAddress::None);
+        std::cin >> server;
+    } while (!server.has_value());
 
     // Create an instance of our custom recorder
-    NetworkRecorder recorder(server, port);
+    NetworkRecorder recorder(server.value(), port);
 
     // Wait for user input...
     std::cin.ignore(10000, '\n');
@@ -134,7 +138,12 @@ void doClient(unsigned short port)
     std::cin.ignore(10000, '\n');
 
     // Start capturing audio data
-    recorder.start(44100);
+    if (!recorder.start(44100))
+    {
+        std::cerr << "Failed to start recorder" << std::endl;
+        return;
+    }
+
     std::cout << "Recording... press enter to stop";
     std::cin.ignore(10000, '\n');
     recorder.stop();
