@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2017 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,20 +22,22 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_SOUND_HPP
-#define SFML_SOUND_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Audio/Export.hpp>
-#include <SFML/Audio/SoundSource.hpp>
-#include <SFML/System/Time.hpp>
-#include <cstdlib>
 
+#include <SFML/Audio/SoundSource.hpp>
+
+#include <memory>
+
+#include <cstdlib>
 
 namespace sf
 {
+class Time;
 class SoundBuffer;
 
 ////////////////////////////////////////////////////////////
@@ -45,13 +47,6 @@ class SoundBuffer;
 class SFML_AUDIO_API Sound : public SoundSource
 {
 public:
-
-    ////////////////////////////////////////////////////////////
-    /// \brief Default constructor
-    ///
-    ////////////////////////////////////////////////////////////
-    Sound();
-
     ////////////////////////////////////////////////////////////
     /// \brief Construct the sound with a buffer
     ///
@@ -60,6 +55,12 @@ public:
     ////////////////////////////////////////////////////////////
     explicit Sound(const SoundBuffer& buffer);
 
+    ////////////////////////////////////////////////////////////
+    /// \brief Disallow construction from a temporary sound buffer
+    ///
+    ////////////////////////////////////////////////////////////
+    Sound(const SoundBuffer&& buffer) = delete;
+
     ////////////////////////////////////////////////////////////
     /// \brief Copy constructor
     ///
@@ -72,7 +73,7 @@ public:
     /// \brief Destructor
     ///
     ////////////////////////////////////////////////////////////
-    ~Sound();
+    ~Sound() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Start or resume playing the sound
@@ -83,10 +84,10 @@ public:
     /// This function uses its own thread so that it doesn't block
     /// the rest of the program while the sound is played.
     ///
-    /// \see pause, stop
+    /// \see `pause`, `stop`
     ///
     ////////////////////////////////////////////////////////////
-    void play();
+    void play() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Pause the sound
@@ -94,51 +95,57 @@ public:
     /// This function pauses the sound if it was playing,
     /// otherwise (sound already paused or stopped) it has no effect.
     ///
-    /// \see play, stop
+    /// \see `play`, `stop`
     ///
     ////////////////////////////////////////////////////////////
-    void pause();
+    void pause() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief stop playing the sound
     ///
     /// This function stops the sound if it was playing or paused,
     /// and does nothing if it was already stopped.
-    /// It also resets the playing position (unlike pause()).
+    /// It also resets the playing position (unlike `pause()`).
     ///
-    /// \see play, pause
+    /// \see `play`, `pause`
     ///
     ////////////////////////////////////////////////////////////
-    void stop();
+    void stop() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Set the source buffer containing the audio data to play
     ///
     /// It is important to note that the sound buffer is not copied,
-    /// thus the sf::SoundBuffer instance must remain alive as long
+    /// thus the `sf::SoundBuffer` instance must remain alive as long
     /// as it is attached to the sound.
     ///
     /// \param buffer Sound buffer to attach to the sound
     ///
-    /// \see getBuffer
+    /// \see `getBuffer`
     ///
     ////////////////////////////////////////////////////////////
     void setBuffer(const SoundBuffer& buffer);
 
+    ////////////////////////////////////////////////////////////
+    /// \brief Disallow setting from a temporary sound buffer
+    ///
+    ////////////////////////////////////////////////////////////
+    void setBuffer(const SoundBuffer&& buffer) = delete;
+
     ////////////////////////////////////////////////////////////
     /// \brief Set whether or not the sound should loop after reaching the end
     ///
     /// If set, the sound will restart from beginning after
     /// reaching the end and so on, until it is stopped or
-    /// setLoop(false) is called.
-    /// The default looping state for sound is false.
+    /// `setLooping(false)` is called.
+    /// The default looping state for sound is `false`.
     ///
-    /// \param loop True to play in loop, false to play once
+    /// \param loop `true` to play in loop, `false` to play once
     ///
-    /// \see getLoop
+    /// \see `isLooping`
     ///
     ////////////////////////////////////////////////////////////
-    void setLoop(bool loop);
+    void setLooping(bool loop);
 
     ////////////////////////////////////////////////////////////
     /// \brief Change the current playing position of the sound
@@ -150,38 +157,49 @@ public:
     ///
     /// \param timeOffset New playing position, from the beginning of the sound
     ///
-    /// \see getPlayingOffset
+    /// \see `getPlayingOffset`
     ///
     ////////////////////////////////////////////////////////////
     void setPlayingOffset(Time timeOffset);
 
     ////////////////////////////////////////////////////////////
-    /// \brief Get the audio buffer attached to the sound
+    /// \brief Set the effect processor to be applied to the sound
     ///
-    /// \return Sound buffer attached to the sound (can be NULL)
+    /// The effect processor is a callable that will be called
+    /// with sound data to be processed.
+    ///
+    /// \param effectProcessor The effect processor to attach to this sound, attach an empty processor to disable processing
     ///
     ////////////////////////////////////////////////////////////
-    const SoundBuffer* getBuffer() const;
+    void setEffectProcessor(EffectProcessor effectProcessor) override;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Get the audio buffer attached to the sound
+    ///
+    /// \return Sound buffer attached to the sound
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] const SoundBuffer& getBuffer() const;
 
     ////////////////////////////////////////////////////////////
     /// \brief Tell whether or not the sound is in loop mode
     ///
-    /// \return True if the sound is looping, false otherwise
+    /// \return `true` if the sound is looping, `false` otherwise
     ///
-    /// \see setLoop
+    /// \see `setLooping`
     ///
     ////////////////////////////////////////////////////////////
-    bool getLoop() const;
+    [[nodiscard]] bool isLooping() const;
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the current playing position of the sound
     ///
     /// \return Current playing position, from the beginning of the sound
     ///
-    /// \see setPlayingOffset
+    /// \see `setPlayingOffset`
     ///
     ////////////////////////////////////////////////////////////
-    Time getPlayingOffset() const;
+    [[nodiscard]] Time getPlayingOffset() const;
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the current status of the sound (stopped, paused, playing)
@@ -189,7 +207,7 @@ public:
     /// \return Current status of the sound
     ///
     ////////////////////////////////////////////////////////////
-    Status getStatus() const;
+    [[nodiscard]] Status getStatus() const override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Overload of assignment operator
@@ -199,66 +217,68 @@ public:
     /// \return Reference to self
     ///
     ////////////////////////////////////////////////////////////
-    Sound& operator =(const Sound& right);
-
-    ////////////////////////////////////////////////////////////
-    /// \brief Reset the internal buffer of the sound
-    ///
-    /// This function is for internal use only, you don't have
-    /// to use it. It is called by the sf::SoundBuffer that
-    /// this sound uses, when it is destroyed in order to prevent
-    /// the sound from using a dead buffer.
-    ///
-    ////////////////////////////////////////////////////////////
-    void resetBuffer();
+    Sound& operator=(const Sound& right);
 
 private:
+    friend class SoundBuffer;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Detach sound from its internal buffer
+    ///
+    /// This allows the sound buffer to temporarily detach the
+    /// sounds that use it when the sound buffer gets updated.
+    ///
+    ////////////////////////////////////////////////////////////
+    void detachBuffer();
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Get the sound object
+    ///
+    /// \return The sound object
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] void* getSound() const override;
 
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    const SoundBuffer* m_buffer; ///< Sound buffer bound to the source
+    struct Impl;
+    const std::unique_ptr<Impl> m_impl; //!< Implementation details
 };
 
 } // namespace sf
 
 
-#endif // SFML_SOUND_HPP
-
-
 ////////////////////////////////////////////////////////////
 /// \class sf::Sound
 /// \ingroup audio
 ///
-/// sf::Sound is the class to use to play sounds.
+/// `sf::Sound` is the class to use to play sounds.
 /// It provides:
 /// \li Control (play, pause, stop)
 /// \li Ability to modify output parameters in real-time (pitch, volume, ...)
 /// \li 3D spatial features (position, attenuation, ...).
 ///
-/// sf::Sound is perfect for playing short sounds that can
+/// `sf::Sound` is perfect for playing short sounds that can
 /// fit in memory and require no latency, like foot steps or
 /// gun shots. For longer sounds, like background musics
-/// or long speeches, rather see sf::Music (which is based
+/// or long speeches, rather see `sf::Music` (which is based
 /// on streaming).
 ///
 /// In order to work, a sound must be given a buffer of audio
-/// data to play. Audio data (samples) is stored in sf::SoundBuffer,
-/// and attached to a sound with the setBuffer() function.
+/// data to play. Audio data (samples) is stored in `sf::SoundBuffer,`
+/// and attached to a sound when it is created or with the `setBuffer()` function.
 /// The buffer object attached to a sound must remain alive
 /// as long as the sound uses it. Note that multiple sounds
 /// can use the same sound buffer at the same time.
 ///
 /// Usage example:
 /// \code
-/// sf::SoundBuffer buffer;
-/// buffer.loadFromFile("sound.wav");
-///
-/// sf::Sound sound;
-/// sound.setBuffer(buffer);
+/// const sf::SoundBuffer buffer("sound.wav");
+/// sf::Sound sound(buffer);
 /// sound.play();
 /// \endcode
 ///
-/// \see sf::SoundBuffer, sf::Music
+/// \see `sf::SoundBuffer`, `sf::Music`
 ///
 ////////////////////////////////////////////////////////////
