@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2017 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,15 +22,19 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_RECTANGLESHAPE_HPP
-#define SFML_RECTANGLESHAPE_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Graphics/Export.hpp>
+
 #include <SFML/Graphics/Shape.hpp>
 
+#include <SFML/System/Vector2.hpp>
+
+#include <cstddef>
+
 
 namespace sf
 {
@@ -41,34 +45,33 @@ namespace sf
 class SFML_GRAPHICS_API RectangleShape : public Shape
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Default constructor
     ///
     /// \param size Size of the rectangle
     ///
     ////////////////////////////////////////////////////////////
-    explicit RectangleShape(const Vector2f& size = Vector2f(0, 0));
+    explicit RectangleShape(Vector2f size = {});
 
     ////////////////////////////////////////////////////////////
     /// \brief Set the size of the rectangle
     ///
     /// \param size New size of the rectangle
     ///
-    /// \see getSize
+    /// \see `getSize`
     ///
     ////////////////////////////////////////////////////////////
-    void setSize(const Vector2f& size);
+    void setSize(Vector2f size);
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the size of the rectangle
     ///
     /// \return Size of the rectangle
     ///
-    /// \see setSize
+    /// \see `setSize`
     ///
     ////////////////////////////////////////////////////////////
-    const Vector2f& getSize() const;
+    [[nodiscard]] Vector2f getSize() const;
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the number of points defining the shape
@@ -77,7 +80,7 @@ public:
     ///         shapes, this number is always 4.
     ///
     ////////////////////////////////////////////////////////////
-    virtual std::size_t getPointCount() const;
+    [[nodiscard]] std::size_t getPointCount() const override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Get a point of the rectangle
@@ -85,36 +88,44 @@ public:
     /// The returned point is in local coordinates, that is,
     /// the shape's transforms (position, rotation, scale) are
     /// not taken into account.
-    /// The result is undefined if \a index is out of the valid range.
+    /// The result is undefined if `index` is out of the valid range.
     ///
     /// \param index Index of the point to get, in range [0 .. 3]
     ///
-    /// \return index-th point of the shape
+    /// \return `index`-th point of the shape
     ///
     ////////////////////////////////////////////////////////////
-    virtual Vector2f getPoint(std::size_t index) const;
+    [[nodiscard]] Vector2f getPoint(std::size_t index) const override;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Get the geometric center of the rectangle
+    ///
+    /// The returned point is in local coordinates, that is,
+    /// the shape's transforms (position, rotation, scale) are
+    /// not taken into account.
+    ///
+    /// \return The geometric center of the shape
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] Vector2f getGeometricCenter() const override;
 
 private:
-
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    Vector2f m_size; ///< Size of the rectangle
+    Vector2f m_size; //!< Size of the rectangle
 };
 
 } // namespace sf
 
 
-#endif // SFML_RECTANGLESHAPE_HPP
-
-
 ////////////////////////////////////////////////////////////
 /// \class sf::RectangleShape
 /// \ingroup graphics
 ///
-/// This class inherits all the functions of sf::Transformable
+/// This class inherits all the functions of `sf::Transformable`
 /// (position, rotation, scale, bounds, ...) as well as the
-/// functions of sf::Shape (outline, color, texture, ...).
+/// functions of `sf::Shape` (outline, color, texture, ...).
 ///
 /// Usage example:
 /// \code
@@ -122,11 +133,11 @@ private:
 /// rectangle.setSize(sf::Vector2f(100, 50));
 /// rectangle.setOutlineColor(sf::Color::Red);
 /// rectangle.setOutlineThickness(5);
-/// rectangle.setPosition(10, 20);
+/// rectangle.setPosition({10, 20});
 /// ...
 /// window.draw(rectangle);
 /// \endcode
 ///
-/// \see sf::Shape, sf::CircleShape, sf::ConvexShape
+/// \see `sf::Shape`, `sf::CircleShape`, `sf::ConvexShape`
 ///
 ////////////////////////////////////////////////////////////
