@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,18 +22,21 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_HTTP_HPP
-#define SFML_HTTP_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Network/Export.hpp>
+
 #include <SFML/Network/IpAddress.hpp>
 #include <SFML/Network/TcpSocket.hpp>
-#include <SFML/System/NonCopyable.hpp>
+
 #include <SFML/System/Time.hpp>
+
+#include <iosfwd>
 #include <map>
+#include <optional>
 #include <string>
 
 
@@ -43,23 +46,21 @@ namespace sf
 /// \brief A HTTP client
 ///
 ////////////////////////////////////////////////////////////
-class SFML_NETWORK_API Http : NonCopyable
+class SFML_NETWORK_API Http
 {
 public:
-
     ////////////////////////////////////////////////////////////
-    /// \brief Define a HTTP request
+    /// \brief HTTP request
     ///
     ////////////////////////////////////////////////////////////
     class SFML_NETWORK_API Request
     {
     public:
-
         ////////////////////////////////////////////////////////////
         /// \brief Enumerate the available HTTP methods for a request
         ///
         ////////////////////////////////////////////////////////////
-        enum Method
+        enum class Method
         {
             Get,   //!< Request in get mode, standard method to retrieve a page
             Post,  //!< Request in post mode, usually to send data to a page
@@ -79,7 +80,7 @@ public:
         /// \param body   Content of the request's body
         ///
         ////////////////////////////////////////////////////////////
-        Request(const std::string& uri = "/", Method method = Get, const std::string& body = "");
+        Request(const std::string& uri = "/", Method method = Method::Get, const std::string& body = "");
 
         ////////////////////////////////////////////////////////////
         /// \brief Set the value of a field
@@ -100,8 +101,8 @@ public:
         /// \brief Set the request method
         ///
         /// See the Method enumeration for a complete list of all
-        /// the availale methods.
-        /// The method is Http::Request::Get by default.
+        /// the available methods.
+        /// The method is `Http::Request::Method::Get` by default.
         ///
         /// \param method Method to use for the request
         ///
@@ -144,7 +145,6 @@ public:
         void setBody(const std::string& body);
 
     private:
-
         friend class Http;
 
         ////////////////////////////////////////////////////////////
@@ -156,7 +156,7 @@ public:
         /// \return String containing the request, ready to be sent
         ///
         ////////////////////////////////////////////////////////////
-        std::string prepare() const;
+        [[nodiscard]] std::string prepare() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Check if the request defines a field
@@ -165,60 +165,59 @@ public:
         ///
         /// \param field Name of the field to test
         ///
-        /// \return True if the field exists, false otherwise
+        /// \return `true` if the field exists, `false` otherwise
         ///
         ////////////////////////////////////////////////////////////
-        bool hasField(const std::string& field) const;
+        [[nodiscard]] bool hasField(const std::string& field) const;
 
         ////////////////////////////////////////////////////////////
         // Types
         ////////////////////////////////////////////////////////////
-        typedef std::map<std::string, std::string> FieldTable;
+        using FieldTable = std::map<std::string, std::string>; // Use an ordered map for predictable payloads
 
         ////////////////////////////////////////////////////////////
         // Member data
         ////////////////////////////////////////////////////////////
-        FieldTable   m_fields;       //!< Fields of the header associated to their value
-        Method       m_method;       //!< Method to use for the request
-        std::string  m_uri;          //!< Target URI of the request
-        unsigned int m_majorVersion; //!< Major HTTP version
-        unsigned int m_minorVersion; //!< Minor HTTP version
-        std::string  m_body;         //!< Body of the request
+        FieldTable   m_fields;          //!< Fields of the header associated to their value
+        Method       m_method;          //!< Method to use for the request
+        std::string  m_uri;             //!< Target URI of the request
+        unsigned int m_majorVersion{1}; //!< Major HTTP version
+        unsigned int m_minorVersion{};  //!< Minor HTTP version
+        std::string  m_body;            //!< Body of the request
     };
 
     ////////////////////////////////////////////////////////////
-    /// \brief Define a HTTP response
+    /// \brief HTTP response
     ///
     ////////////////////////////////////////////////////////////
     class SFML_NETWORK_API Response
     {
     public:
-
         ////////////////////////////////////////////////////////////
         /// \brief Enumerate all the valid status codes for a response
         ///
         ////////////////////////////////////////////////////////////
-        enum Status
+        enum class Status
         {
             // 2xx: success
-            Ok             = 200, //!< Most common code returned when operation was successful
-            Created        = 201, //!< The resource has successfully been created
-            Accepted       = 202, //!< The request has been accepted, but will be processed later by the server
-            NoContent      = 204, //!< The server didn't send any data in return
-            ResetContent   = 205, //!< The server informs the client that it should clear the view (form) that caused the request to be sent
+            Ok        = 200, //!< Most common code returned when operation was successful
+            Created   = 201, //!< The resource has successfully been created
+            Accepted  = 202, //!< The request has been accepted, but will be processed later by the server
+            NoContent = 204, //!< The server didn't send any data in return
+            ResetContent = 205, //!< The server informs the client that it should clear the view (form) that caused the request to be sent
             PartialContent = 206, //!< The server has sent a part of the resource, as a response to a partial GET request
 
             // 3xx: redirection
             MultipleChoices  = 300, //!< The requested page can be accessed from several locations
             MovedPermanently = 301, //!< The requested page has permanently moved to a new location
             MovedTemporarily = 302, //!< The requested page has temporarily moved to a new location
-            NotModified      = 304, //!< For conditional requests, means the requested page hasn't changed and doesn't need to be refreshed
+            NotModified = 304, //!< For conditional requests, means the requested page hasn't changed and doesn't need to be refreshed
 
             // 4xx: client error
-            BadRequest          = 400, //!< The server couldn't understand the request (syntax error)
-            Unauthorized        = 401, //!< The requested page needs an authentication to be accessed
-            Forbidden           = 403, //!< The requested page cannot be accessed at all, even with authentication
-            NotFound            = 404, //!< The requested page doesn't exist
+            BadRequest   = 400,        //!< The server couldn't understand the request (syntax error)
+            Unauthorized = 401,        //!< The requested page needs an authentication to be accessed
+            Forbidden    = 403,        //!< The requested page cannot be accessed at all, even with authentication
+            NotFound     = 404,        //!< The requested page doesn't exist
             RangeNotSatisfiable = 407, //!< The server can't satisfy the partial GET request (with a "Range" header field)
 
             // 5xx: server error
@@ -234,18 +233,10 @@ public:
             ConnectionFailed = 1001  //!< Connection with server failed
         };
 
-        ////////////////////////////////////////////////////////////
-        /// \brief Default constructor
-        ///
-        /// Constructs an empty response.
-        ///
-        ////////////////////////////////////////////////////////////
-        Response();
-
         ////////////////////////////////////////////////////////////
         /// \brief Get the value of a field
         ///
-        /// If the field \a field is not found in the response header,
+        /// If the field `field` is not found in the response header,
         /// the empty string is returned. This function uses
         /// case-insensitive comparisons.
         ///
@@ -254,7 +245,7 @@ public:
         /// \return Value of the field, or empty string if not found
         ///
         ////////////////////////////////////////////////////////////
-        const std::string& getField(const std::string& field) const;
+        [[nodiscard]] const std::string& getField(const std::string& field) const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the response status code
@@ -267,27 +258,27 @@ public:
         /// \return Status code of the response
         ///
         ////////////////////////////////////////////////////////////
-        Status getStatus() const;
+        [[nodiscard]] Status getStatus() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the major HTTP version number of the response
         ///
         /// \return Major HTTP version number
         ///
-        /// \see getMinorHttpVersion
+        /// \see `getMinorHttpVersion`
         ///
         ////////////////////////////////////////////////////////////
-        unsigned int getMajorHttpVersion() const;
+        [[nodiscard]] unsigned int getMajorHttpVersion() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the minor HTTP version number of the response
         ///
         /// \return Minor HTTP version number
         ///
-        /// \see getMajorHttpVersion
+        /// \see `getMajorHttpVersion`
         ///
         ////////////////////////////////////////////////////////////
-        unsigned int getMinorHttpVersion() const;
+        [[nodiscard]] unsigned int getMinorHttpVersion() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the body of the response
@@ -301,16 +292,15 @@ public:
         /// \return The response body
         ///
         ////////////////////////////////////////////////////////////
-        const std::string& getBody() const;
+        [[nodiscard]] const std::string& getBody() const;
 
     private:
-
         friend class Http;
 
         ////////////////////////////////////////////////////////////
         /// \brief Construct the header from a response string
         ///
-        /// This function is used by Http to build the response
+        /// This function is used by `Http` to build the response
         /// of a request.
         ///
         /// \param data Content of the response to parse
@@ -322,39 +312,39 @@ public:
         ////////////////////////////////////////////////////////////
         /// \brief Read values passed in the answer header
         ///
-        /// This function is used by Http to extract values passed
+        /// This function is used by `Http` to extract values passed
         /// in the response.
         ///
         /// \param in String stream containing the header values
         ///
         ////////////////////////////////////////////////////////////
-        void parseFields(std::istream &in);
+        void parseFields(std::istream& in);
 
         ////////////////////////////////////////////////////////////
         // Types
         ////////////////////////////////////////////////////////////
-        typedef std::map<std::string, std::string> FieldTable;
+        using FieldTable = std::map<std::string, std::string>; // Use an ordered map for predictable payloads
 
         ////////////////////////////////////////////////////////////
         // Member data
         ////////////////////////////////////////////////////////////
-        FieldTable   m_fields;       //!< Fields of the header
-        Status       m_status;       //!< Status code
-        unsigned int m_majorVersion; //!< Major HTTP version
-        unsigned int m_minorVersion; //!< Minor HTTP version
-        std::string  m_body;         //!< Body of the response
+        FieldTable   m_fields;                           //!< Fields of the header
+        Status       m_status{Status::ConnectionFailed}; //!< Status code
+        unsigned int m_majorVersion{};                   //!< Major HTTP version
+        unsigned int m_minorVersion{};                   //!< Minor HTTP version
+        std::string  m_body;                             //!< Body of the response
     };
 
     ////////////////////////////////////////////////////////////
     /// \brief Default constructor
     ///
     ////////////////////////////////////////////////////////////
-    Http();
+    Http() = default;
 
     ////////////////////////////////////////////////////////////
     /// \brief Construct the HTTP client with the target host
     ///
-    /// This is equivalent to calling setHost(host, port).
+    /// This is equivalent to calling `setHost(host, port)`.
     /// The port has a default value of 0, which means that the
     /// HTTP client will use the right port according to the
     /// protocol used (80 for HTTP). You should leave it like
@@ -367,6 +357,18 @@ public:
     ////////////////////////////////////////////////////////////
     Http(const std::string& host, unsigned short port = 0);
 
+    ////////////////////////////////////////////////////////////
+    /// \brief Deleted copy constructor
+    ///
+    ////////////////////////////////////////////////////////////
+    Http(const Http&) = delete;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Deleted copy assignment
+    ///
+    ////////////////////////////////////////////////////////////
+    Http& operator=(const Http&) = delete;
+
     ////////////////////////////////////////////////////////////
     /// \brief Set the target host
     ///
@@ -387,13 +389,13 @@ public:
     ////////////////////////////////////////////////////////////
     /// \brief Send a HTTP request and return the server's response.
     ///
-    /// You must have a valid host before sending a request (see setHost).
+    /// You must have a valid host before sending a request (see `setHost`).
     /// Any missing mandatory header field in the request will be added
     /// with an appropriate value.
     /// Warning: this function waits for the server's response and may
     /// not return instantly; use a thread if you don't want to block your
     /// application, or use a timeout to limit the time to wait. A value
-    /// of Time::Zero means that the client will use the system default timeout
+    /// of `Time::Zero` means that the client will use the system default timeout
     /// (which is usually pretty long).
     ///
     /// \param request Request to send
@@ -402,55 +404,51 @@ public:
     /// \return Server's response
     ///
     ////////////////////////////////////////////////////////////
-    Response sendRequest(const Request& request, Time timeout = Time::Zero);
+    [[nodiscard]] Response sendRequest(const Request& request, Time timeout = Time::Zero);
 
 private:
-
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    TcpSocket      m_connection; //!< Connection to the host
-    IpAddress      m_host;       //!< Web host address
-    std::string    m_hostName;   //!< Web host name
-    unsigned short m_port;       //!< Port used for connection with host
+    TcpSocket                m_connection; //!< Connection to the host
+    std::optional<IpAddress> m_host;       //!< Web host address
+    std::string              m_hostName;   //!< Web host name
+    unsigned short           m_port{};     //!< Port used for connection with host
 };
 
 } // namespace sf
 
 
-#endif // SFML_HTTP_HPP
-
-
 ////////////////////////////////////////////////////////////
 /// \class sf::Http
 /// \ingroup network
 ///
-/// sf::Http is a very simple HTTP client that allows you
+/// `sf::Http` is a very simple HTTP client that allows you
 /// to communicate with a web server. You can retrieve
 /// web pages, send data to an interactive resource,
 /// download a remote file, etc. The HTTPS protocol is
 /// not supported.
 ///
 /// The HTTP client is split into 3 classes:
-/// \li sf::Http::Request
-/// \li sf::Http::Response
-/// \li sf::Http
+/// \li `sf::Http::Request`
+/// \li `sf::Http::Response`
+/// \li `sf::Http`
 ///
-/// sf::Http::Request builds the request that will be
+/// `sf::Http::Request` builds the request that will be
 /// sent to the server. A request is made of:
 /// \li a method (what you want to do)
 /// \li a target URI (usually the name of the web page or file)
 /// \li one or more header fields (options that you can pass to the server)
 /// \li an optional body (for POST requests)
 ///
-/// sf::Http::Response parse the response from the web server
+/// `sf::Http::Response` parse the response from the web server
 /// and provides getters to read them. The response contains:
 /// \li a status code
 /// \li header fields (that may be answers to the ones that you requested)
 /// \li a body, which contains the contents of the requested resource
 ///
-/// sf::Http provides a simple function, SendRequest, to send a
-/// sf::Http::Request and return the corresponding sf::Http::Response
+/// `sf::Http` provides a simple function, SendRequest, to send a
+/// `sf::Http::Request` and return the corresponding `sf::Http::Response`
 /// from the server.
 ///
 /// Usage example:
@@ -469,7 +467,7 @@ private:
 ///
 /// // Check the status code and display the result
 /// sf::Http::Response::Status status = response.getStatus();
-/// if (status == sf::Http::Response::Ok)
+/// if (status == sf::Http::Response::Status::Ok)
 /// {
 ///     std::cout << response.getBody() << std::endl;
 /// }
