@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2017 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,8 +22,9 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_VECTOR3_HPP
-#define SFML_VECTOR3_HPP
+#pragma once
+
+#include <SFML/System/Export.hpp>
 
 
 namespace sf
@@ -37,235 +38,283 @@ template <typename T>
 class Vector3
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Default constructor
     ///
-    /// Creates a Vector3(0, 0, 0).
+    /// Creates a `Vector3(0, 0, 0)`.
     ///
     ////////////////////////////////////////////////////////////
-    Vector3();
+    constexpr Vector3() = default;
 
     ////////////////////////////////////////////////////////////
     /// \brief Construct the vector from its coordinates
     ///
-    /// \param X X coordinate
-    /// \param Y Y coordinate
-    /// \param Z Z coordinate
+    /// \param x X coordinate
+    /// \param y Y coordinate
+    /// \param z Z coordinate
     ///
     ////////////////////////////////////////////////////////////
-    Vector3(T X, T Y, T Z);
+    constexpr Vector3(T x, T y, T z);
 
     ////////////////////////////////////////////////////////////
-    /// \brief Construct the vector from another type of vector
-    ///
-    /// This constructor doesn't replace the copy constructor,
-    /// it's called only when U != T.
-    /// A call to this constructor will fail to compile if U
-    /// is not convertible to T.
-    ///
-    /// \param vector Vector to convert
+    /// \brief Converts the vector to another type of vector
     ///
     ////////////////////////////////////////////////////////////
     template <typename U>
-    explicit Vector3(const Vector3<U>& vector);
+    constexpr explicit operator Vector3<U>() const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Length of the vector <i><b>(floating-point)</b></i>.
+    ///
+    /// If you are not interested in the actual length, but only in comparisons, consider using `lengthSquared()`.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] SFML_SYSTEM_API T length() const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Square of vector's length.
+    ///
+    /// Suitable for comparisons, more efficient than `length()`.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] constexpr T lengthSquared() const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Vector with same direction but length 1 <i><b>(floating-point)</b></i>.
+    ///
+    /// \pre `*this` is no zero vector.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] SFML_SYSTEM_API Vector3 normalized() const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Dot product of two 3D vectors.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] constexpr T dot(const Vector3& rhs) const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Cross product of two 3D vectors.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] constexpr Vector3 cross(const Vector3& rhs) const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Component-wise multiplication of `*this` and `rhs`.
+    ///
+    /// Computes `(lhs.x*rhs.x, lhs.y*rhs.y, lhs.z*rhs.z)`.
+    ///
+    /// Scaling is the most common use case for component-wise multiplication/division.
+    /// This operation is also known as the Hadamard or Schur product.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] constexpr Vector3 componentWiseMul(const Vector3& rhs) const;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Component-wise division of `*this` and `rhs`.
+    ///
+    /// Computes `(lhs.x/rhs.x, lhs.y/rhs.y, lhs.z/rhs.z)`.
+    ///
+    /// Scaling is the most common use case for component-wise multiplication/division.
+    ///
+    /// \pre Neither component of `rhs` is zero.
+    ///
+    ////////////////////////////////////////////////////////////
+    [[nodiscard]] constexpr Vector3 componentWiseDiv(const Vector3& rhs) const;
 
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    T x; ///< X coordinate of the vector
-    T y; ///< Y coordinate of the vector
-    T z; ///< Z coordinate of the vector
+    T x{}; //!< X coordinate of the vector
+    T y{}; //!< Y coordinate of the vector
+    T z{}; //!< Z coordinate of the vector
 };
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of unary operator -
+/// \brief Overload of unary `operator-`
 ///
 /// \param left Vector to negate
 ///
-/// \return Memberwise opposite of the vector
+/// \return Member-wise opposite of the vector
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator -(const Vector3<T>& left);
+[[nodiscard]] constexpr Vector3<T> operator-(const Vector3<T>& left);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator +=
+/// \brief Overload of binary `operator+=`
 ///
-/// This operator performs a memberwise addition of both vectors,
-/// and assigns the result to \a left.
+/// This operator performs a member-wise addition of both vectors,
+/// and assigns the result to `left`.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return Reference to \a left
+/// \return Reference to `left`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T>& operator +=(Vector3<T>& left, const Vector3<T>& right);
+constexpr Vector3<T>& operator+=(Vector3<T>& left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator -=
+/// \brief Overload of binary `operator-=`
 ///
-/// This operator performs a memberwise subtraction of both vectors,
-/// and assigns the result to \a left.
+/// This operator performs a member-wise subtraction of both vectors,
+/// and assigns the result to `left`.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return Reference to \a left
+/// \return Reference to `left`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T>& operator -=(Vector3<T>& left, const Vector3<T>& right);
+constexpr Vector3<T>& operator-=(Vector3<T>& left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator +
+/// \brief Overload of binary `operator+`
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return Memberwise addition of both vectors
+/// \return Member-wise addition of both vectors
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator +(const Vector3<T>& left, const Vector3<T>& right);
+[[nodiscard]] constexpr Vector3<T> operator+(const Vector3<T>& left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator -
+/// \brief Overload of binary `operator-`
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return Memberwise subtraction of both vectors
+/// \return Member-wise subtraction of both vectors
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator -(const Vector3<T>& left, const Vector3<T>& right);
+[[nodiscard]] constexpr Vector3<T> operator-(const Vector3<T>& left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator *
+/// \brief Overload of binary `operator*`
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a scalar value)
 ///
-/// \return Memberwise multiplication by \a right
+/// \return Member-wise multiplication by `right`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator *(const Vector3<T>& left, T right);
+[[nodiscard]] constexpr Vector3<T> operator*(const Vector3<T>& left, T right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator *
+/// \brief Overload of binary `operator*`
 ///
 /// \param left  Left operand (a scalar value)
 /// \param right Right operand (a vector)
 ///
-/// \return Memberwise multiplication by \a left
+/// \return Member-wise multiplication by `left`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator *(T left, const Vector3<T>& right);
+[[nodiscard]] constexpr Vector3<T> operator*(T left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator *=
+/// \brief Overload of binary `operator*=`
 ///
-/// This operator performs a memberwise multiplication by \a right,
-/// and assigns the result to \a left.
+/// This operator performs a member-wise multiplication by `right`,
+/// and assigns the result to `left`.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a scalar value)
 ///
-/// \return Reference to \a left
+/// \return Reference to `left`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T>& operator *=(Vector3<T>& left, T right);
+constexpr Vector3<T>& operator*=(Vector3<T>& left, T right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator /
+/// \brief Overload of binary `operator/`
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a scalar value)
 ///
-/// \return Memberwise division by \a right
+/// \return Member-wise division by `right`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T> operator /(const Vector3<T>& left, T right);
+[[nodiscard]] constexpr Vector3<T> operator/(const Vector3<T>& left, T right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator /=
+/// \brief Overload of binary `operator/=`
 ///
-/// This operator performs a memberwise division by \a right,
-/// and assigns the result to \a left.
+/// This operator performs a member-wise division by `right`,
+/// and assigns the result to `left`.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a scalar value)
 ///
-/// \return Reference to \a left
+/// \return Reference to `left`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-Vector3<T>& operator /=(Vector3<T>& left, T right);
+constexpr Vector3<T>& operator/=(Vector3<T>& left, T right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator ==
+/// \brief Overload of binary `operator==`
 ///
 /// This operator compares strict equality between two vectors.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return True if \a left is equal to \a right
+/// \return `true` if `left` is equal to `right`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-bool operator ==(const Vector3<T>& left, const Vector3<T>& right);
+[[nodiscard]] constexpr bool operator==(const Vector3<T>& left, const Vector3<T>& right);
 
 ////////////////////////////////////////////////////////////
 /// \relates Vector3
-/// \brief Overload of binary operator !=
+/// \brief Overload of binary `operator!=`
 ///
 /// This operator compares strict difference between two vectors.
 ///
 /// \param left  Left operand (a vector)
 /// \param right Right operand (a vector)
 ///
-/// \return True if \a left is not equal to \a right
+/// \return `true` if `left` is not equal to `right`
 ///
 ////////////////////////////////////////////////////////////
 template <typename T>
-bool operator !=(const Vector3<T>& left, const Vector3<T>& right);
+[[nodiscard]] constexpr bool operator!=(const Vector3<T>& left, const Vector3<T>& right);
 
-#include <SFML/System/Vector3.inl>
-
-// Define the most common types
-typedef Vector3<int>   Vector3i;
-typedef Vector3<float> Vector3f;
+// Aliases for the most common types
+using Vector3i = Vector3<int>;
+using Vector3f = Vector3<float>;
 
 } // namespace sf
 
-
-#endif // SFML_VECTOR3_HPP
+#include <SFML/System/Vector3.inl>
 
 
 ////////////////////////////////////////////////////////////
 /// \class sf::Vector3
 /// \ingroup system
 ///
-/// sf::Vector3 is a simple class that defines a mathematical
+/// `sf::Vector3` is a simple class that defines a mathematical
 /// vector with three coordinates (x, y and z). It can be used to
 /// represent anything that has three dimensions: a size, a point,
 /// a velocity, etc.
@@ -273,30 +322,35 @@ typedef Vector3<float> Vector3f;
 /// The template parameter T is the type of the coordinates. It
 /// can be any type that supports arithmetic operations (+, -, /, *)
 /// and comparisons (==, !=), for example int or float.
+/// Note that some operations are only meaningful for vectors where T is
+/// a floating point type (e.g. float or double), often because
+/// results cannot be represented accurately with integers.
+/// The method documentation mentions "(floating-point)" in those cases.
 ///
-/// You generally don't have to care about the templated form (sf::Vector3<T>),
-/// the most common specializations have special typedefs:
-/// \li sf::Vector3<float> is sf::Vector3f
-/// \li sf::Vector3<int> is sf::Vector3i
+/// You generally don't have to care about the templated form (`sf::Vector3<T>`),
+/// the most common specializations have special type aliases:
+/// \li `sf::Vector3<float>` is `sf::Vector3f`
+/// \li `sf::Vector3<int>` is `sf::Vector3i`
 ///
-/// The sf::Vector3 class has a small and simple interface, its x and y members
-/// can be accessed directly (there are no accessors like setX(), getX()) and it
-/// contains no mathematical function like dot product, cross product, length, etc.
+/// The `sf::Vector3` class has a small and simple interface, its x, y and z members
+/// can be accessed directly (there are no accessors like `setX()`, `getX()`).
 ///
 /// Usage example:
 /// \code
-/// sf::Vector3f v1(16.5f, 24.f, -8.2f);
-/// v1.x = 18.2f;
-/// float y = v1.y;
-/// float z = v1.z;
+/// sf::Vector3f v(16.5f, 24.f, -3.2f);
+/// v.x = 18.2f;
+/// float y = v.y;
 ///
-/// sf::Vector3f v2 = v1 * 5.f;
-/// sf::Vector3f v3;
-/// v3 = v1 + v2;
+/// sf::Vector3f w = v * 5.f;
+/// sf::Vector3f u;
+/// u = v + w;
 ///
-/// bool different = (v2 != v3);
+/// float s = v.dot(w);
+/// sf::Vector3f t = v.cross(w);
+///
+/// bool different = (v != u);
 /// \endcode
 ///
-/// Note: for 2-dimensional vectors, see sf::Vector2.
+/// Note: for 2-dimensional vectors, see `sf::Vector2`.
 ///
 ////////////////////////////////////////////////////////////
