@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,74 +26,112 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Audio/InputSoundFile.hpp>
-#include <SFML/Audio/SoundFileReader.hpp>
 #include <SFML/Audio/SoundFileFactory.hpp>
-#include <SFML/System/InputStream.hpp>
-#include <SFML/System/FileInputStream.hpp>
-#include <SFML/System/MemoryInputStream.hpp>
+#include <SFML/Audio/SoundFileReader.hpp>
+
 #include <SFML/System/Err.hpp>
-#include <iostream>
-#include <algorithm>
+#include <SFML/System/Exception.hpp>
+#include <SFML/System/FileInputStream.hpp>
+#include <SFML/System/InputStream.hpp>
+#include <SFML/System/MemoryInputStream.hpp>
+#include <SFML/System/Time.hpp>
+#include <SFML/System/Utils.hpp>
+
+#include <ostream>
+#include <utility>
+
+#include <cassert>
+#include <cstdint>
 
 
 namespace sf
 {
 ////////////////////////////////////////////////////////////
-InputSoundFile::InputSoundFile() :
-m_reader      (NULL),
-m_stream      (NULL),
-m_streamOwned (false),
-m_sampleOffset   (0),
-m_sampleCount (0),
-m_channelCount(0),
-m_sampleRate  (0)
+InputSoundFile::StreamDeleter::StreamDeleter(bool theOwned) : owned(theOwned)
 {
 }
 
 
 ////////////////////////////////////////////////////////////
-InputSoundFile::~InputSoundFile()
+template <typename T>
+InputSoundFile::StreamDeleter::StreamDeleter(const std::default_delete<T>&)
 {
-    // Close the file in case it was open
-    close();
 }
 
 
 ////////////////////////////////////////////////////////////
-bool InputSoundFile::openFromFile(const std::string& filename)
+void InputSoundFile::StreamDeleter::operator()(InputStream* ptr) const
+{
+    if (owned)
+        delete ptr;
+}
+
+
+////////////////////////////////////////////////////////////
+InputSoundFile::InputSoundFile(const std::filesystem::path& filename)
+{
+    if (!openFromFile(filename))
+        throw sf::Exception("Failed to open input sound file");
+}
+
+
+////////////////////////////////////////////////////////////
+InputSoundFile::InputSoundFile(const void* data, std::size_t sizeInBytes)
+{
+    if (!openFromMemory(data, sizeInBytes))
+        throw sf::Exception("Failed to open input sound file from memory");
+}
+
+
+////////////////////////////////////////////////////////////
+InputSoundFile::InputSoundFile(InputStream& stream)
+{
+    if (!openFromStream(stream))
+        throw sf::Exception("Failed to open input sound file from stream");
+}
+
+
+////////////////////////////////////////////////////////////
+bool InputSoundFile::openFromFile(const std::filesystem::path& filename)
 {
     // If the file is already open, first close it
     close();
 
     // Find a suitable reader for the file type
-    m_reader = SoundFileFactory::createReaderFromFilename(filename);
-    if (!m_reader)
+    auto reader = SoundFileFactory::createReaderFromFilename(filename);
+    if (!reader)
         return false;
 
     // Wrap the file into a stream
-    FileInputStream* file = new FileInputStream;
-    m_stream = file;
-    m_streamOwned = true;
+    auto file = std::make_unique<FileInputStream>();
 
     // Open it
     if (!file->open(filename))
     {
-        close();
+        err() << "Failed to open input sound file from file (couldn't open file input stream)\n"
+              << formatDebugPathInfo(filename) << std::endl;
+
         return false;
     }
 
     // Pass the stream to the reader
-    SoundFileReader::Info info;
-    if (!m_reader->open(*file, info))
+    const auto info = reader->open(*file);
+    if (!info)
     {
-        close();
+        err() << "Failed to open input sound file from file (reader open failure)\n"
+              << formatDebugPathInfo(filename) << std::endl;
+
         return false;
     }
 
+    // Take ownership of successfully opened reader and stream
+    m_reader = std::move(reader);
+    m_stream = std::move(file);
+
     // Retrieve the attributes of the open sound file
-    m_sampleCount = info.sampleCount;
-    m_channelCount = info.channelCount;
-    m_sampleRate = info.sampleRate;
+    m_sampleCount = info->sampleCount;
+    m_sampleRate  = info->sampleRate;
+    m_channelMap  = info->channelMap;
 
     return true;
 }
@@ -106,30 +144,32 @@ bool InputSoundFile::openFromMemory(const void* data, std::size_t sizeInBytes)
     close();
 
     // Find a suitable reader for the file type
-    m_reader = SoundFileFactory::createReaderFromMemory(data, sizeInBytes);
-    if (!m_reader)
-        return false;
-
-    // Wrap the memory file into a stream
-    MemoryInputStream* memory = new MemoryInputStream;
-    m_stream = memory;
-    m_streamOwned = true;
-
-    // Open it
-    memory->open(data, sizeInBytes);
-
-    // Pass the stream to the reader
-    SoundFileReader::Info info;
-    if (!m_reader->open(*memory, info))
+    auto reader = SoundFileFactory::createReaderFromMemory(data, sizeInBytes);
+    if (!reader)
     {
-        close();
+        // Error message generated in called function.
         return false;
     }
 
+    // Wrap the memory file into a stream
+    auto memory = std::make_unique<MemoryInputStream>(data, sizeInBytes);
+
+    // Pass the stream to the reader
+    const auto info = reader->open(*memory);
+    if (!info)
+    {
+        err() << "Failed to open input sound file from memory (reader open failure)" << std::endl;
+        return false;
+    }
+
+    // Take ownership of successfully opened reader and stream
+    m_reader = std::move(reader);
+    m_stream = std::move(memory);
+
     // Retrieve the attributes of the open sound file
-    m_sampleCount = info.sampleCount;
-    m_channelCount = info.channelCount;
-    m_sampleRate = info.sampleRate;
+    m_sampleCount = info->sampleCount;
+    m_sampleRate  = info->sampleRate;
+    m_channelMap  = info->channelMap;
 
     return true;
 }
@@ -142,13 +182,12 @@ bool InputSoundFile::openFromStream(InputStream& stream)
     close();
 
     // Find a suitable reader for the file type
-    m_reader = SoundFileFactory::createReaderFromStream(stream);
-    if (!m_reader)
+    auto reader = SoundFileFactory::createReaderFromStream(stream);
+    if (!reader)
+    {
+        // Error message generated in called function.
         return false;
-
-    // store the stream
-    m_stream = &stream;
-    m_streamOwned = false;
+    }
 
     // Don't forget to reset the stream to its beginning before re-opening it
     if (stream.seek(0) != 0)
@@ -158,24 +197,28 @@ bool InputSoundFile::openFromStream(InputStream& stream)
     }
 
     // Pass the stream to the reader
-    SoundFileReader::Info info;
-    if (!m_reader->open(stream, info))
+    const auto info = reader->open(stream);
+    if (!info)
     {
-        close();
+        err() << "Failed to open input sound file from stream (reader open failure)" << std::endl;
         return false;
     }
 
+    // Take ownership of reader and store a reference to the stream without taking ownership
+    m_reader = std::move(reader);
+    m_stream = {&stream, false};
+
     // Retrieve the attributes of the open sound file
-    m_sampleCount = info.sampleCount;
-    m_channelCount = info.channelCount;
-    m_sampleRate = info.sampleRate;
+    m_sampleCount = info->sampleCount;
+    m_sampleRate  = info->sampleRate;
+    m_channelMap  = info->channelMap;
 
     return true;
 }
 
 
 ////////////////////////////////////////////////////////////
-Uint64 InputSoundFile::getSampleCount() const
+std::uint64_t InputSoundFile::getSampleCount() const
 {
     return m_sampleCount;
 }
@@ -184,7 +227,7 @@ Uint64 InputSoundFile::getSampleCount() const
 ////////////////////////////////////////////////////////////
 unsigned int InputSoundFile::getChannelCount() const
 {
-    return m_channelCount;
+    return static_cast<unsigned int>(m_channelMap.size());
 }
 
 
@@ -195,14 +238,22 @@ unsigned int InputSoundFile::getSampleRate() const
 }
 
 
+////////////////////////////////////////////////////////////
+const std::vector<SoundChannel>& InputSoundFile::getChannelMap() const
+{
+    return m_channelMap;
+}
+
+
 ////////////////////////////////////////////////////////////
 Time InputSoundFile::getDuration() const
 {
     // Make sure we don't divide by 0
-    if (m_channelCount == 0 || m_sampleRate == 0)
+    if (m_channelMap.empty() || m_sampleRate == 0)
         return Time::Zero;
 
-    return seconds(static_cast<float>(m_sampleCount) / static_cast<float>(m_channelCount) / static_cast<float>(m_sampleRate));
+    return seconds(
+        static_cast<float>(m_sampleCount) / static_cast<float>(m_channelMap.size()) / static_cast<float>(m_sampleRate));
 }
 
 
@@ -210,28 +261,31 @@ Time InputSoundFile::getDuration() const
 Time InputSoundFile::getTimeOffset() const
 {
     // Make sure we don't divide by 0
-    if (m_channelCount == 0 || m_sampleRate == 0)
+    if (m_channelMap.empty() || m_sampleRate == 0)
         return Time::Zero;
 
-    return seconds(static_cast<float>(m_sampleOffset) / static_cast<float>(m_channelCount) / static_cast<float>(m_sampleRate));
+    return seconds(
+        static_cast<float>(m_sampleOffset) / static_cast<float>(m_channelMap.size()) / static_cast<float>(m_sampleRate));
 }
 
 
 ////////////////////////////////////////////////////////////
-Uint64 InputSoundFile::getSampleOffset() const
+std::uint64_t InputSoundFile::getSampleOffset() const
 {
     return m_sampleOffset;
 }
 
 
 ////////////////////////////////////////////////////////////
-void InputSoundFile::seek(Uint64 sampleOffset)
+void InputSoundFile::seek(std::uint64_t sampleOffset)
 {
-    if (m_reader && m_channelCount != 0)
+    assert(m_reader);
+
+    if (!m_channelMap.empty())
     {
         // The reader handles an overrun gracefully, but we
         // pre-check to keep our known position consistent
-        m_sampleOffset = std::min(sampleOffset / m_channelCount * m_channelCount, m_sampleCount);
+        m_sampleOffset = std::min(sampleOffset / m_channelMap.size() * m_channelMap.size(), m_sampleCount);
         m_reader->seek(m_sampleOffset);
     }
 }
@@ -240,15 +294,17 @@ void InputSoundFile::seek(Uint64 sampleOffset)
 ////////////////////////////////////////////////////////////
 void InputSoundFile::seek(Time timeOffset)
 {
-    seek(static_cast<Uint64>(timeOffset.asSeconds() * static_cast<float>(m_sampleRate)) * m_channelCount);
+    seek(static_cast<std::uint64_t>(timeOffset.asSeconds() * static_cast<float>(m_sampleRate)) * m_channelMap.size());
 }
 
 
 ////////////////////////////////////////////////////////////
-Uint64 InputSoundFile::read(Int16* samples, Uint64 maxCount)
+std::uint64_t InputSoundFile::read(std::int16_t* samples, std::uint64_t maxCount)
 {
-    Uint64 readSamples = 0;
-    if (m_reader && samples && maxCount)
+    assert(m_reader);
+
+    std::uint64_t readSamples = 0;
+    if (samples && maxCount)
         readSamples = m_reader->read(samples, maxCount);
     m_sampleOffset += readSamples;
     return readSamples;
@@ -258,23 +314,7 @@ Uint64 InputSoundFile::read(Int16* samples, Uint64 maxCount)
 ////////////////////////////////////////////////////////////
 void InputSoundFile::close()
 {
-    // Destroy the reader
-    delete m_reader;
-    m_reader = NULL;
-
-    // Destroy the stream if we own it
-    if (m_streamOwned)
-    {
-        delete m_stream;
-        m_streamOwned = false;
-    }
-    m_stream = NULL;
-    m_sampleOffset = 0;
-
-    // Reset the sound file attributes
-    m_sampleCount = 0;
-    m_channelCount = 0;
-    m_sampleRate = 0;
+    *this = {};
 }
 
 } // namespace sf
