@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,29 +25,67 @@
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
+#include <SFML/Audio/InputSoundFile.hpp>
 #include <SFML/Audio/Music.hpp>
-#include <SFML/Audio/ALCheck.hpp>
-#include <SFML/System/Lock.hpp>
-#include <SFML/System/Err.hpp>
-#include <fstream>
-#include <algorithm>
 
-#if defined(__APPLE__)
-    #if defined(__clang__)
-        #pragma clang diagnostic ignored "-Wdeprecated-declarations"
-    #elif defined(__GNUC__)
-        #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-    #endif
-#endif
+#include <SFML/System/Err.hpp>
+#include <SFML/System/Exception.hpp>
+#include <SFML/System/Time.hpp>
+
+#include <algorithm>
+#include <mutex>
+#include <ostream>
+
 
 namespace sf
 {
 ////////////////////////////////////////////////////////////
-Music::Music() :
-m_file      (),
-m_loopSpan  (0, 0)
+struct Music::Impl
 {
+    InputSoundFile            file;     //!< The streamed music file
+    std::vector<std::int16_t> samples;  //!< Temporary buffer of samples
+    std::recursive_mutex      mutex;    //!< Mutex protecting the data
+    Span<std::uint64_t>       loopSpan; //!< Loop Range Specifier
 
+    void initialize()
+    {
+        // Compute the music positions
+        loopSpan.offset = 0;
+        loopSpan.length = file.getSampleCount();
+
+        // Resize the internal buffer so that it can contain 1 second of audio samples
+        samples.resize(file.getSampleRate() * file.getChannelCount());
+    }
+};
+
+
+////////////////////////////////////////////////////////////
+Music::Music() : m_impl(std::make_unique<Impl>())
+{
+}
+
+
+////////////////////////////////////////////////////////////
+Music::Music(const std::filesystem::path& filename) : Music()
+{
+    if (!openFromFile(filename))
+        throw sf::Exception("Failed to open music from file");
+}
+
+
+////////////////////////////////////////////////////////////
+Music::Music(const void* data, std::size_t sizeInBytes) : Music()
+{
+    if (!openFromMemory(data, sizeInBytes))
+        throw sf::Exception("Failed to open music from memory");
+}
+
+
+////////////////////////////////////////////////////////////
+Music::Music(InputStream& stream) : Music()
+{
+    if (!openFromStream(stream))
+        throw sf::Exception("Failed to open music from stream");
 }
 
 
@@ -55,22 +93,39 @@ m_loopSpan  (0, 0)
 Music::~Music()
 {
     // We must stop before destroying the file
-    stop();
+    if (m_impl != nullptr)
+    {
+        stop();
+    }
 }
 
 
 ////////////////////////////////////////////////////////////
-bool Music::openFromFile(const std::string& filename)
+Music::Music(Music&&) noexcept = default;
+
+
+////////////////////////////////////////////////////////////
+Music& Music::operator=(Music&&) noexcept = default;
+
+
+////////////////////////////////////////////////////////////
+bool Music::openFromFile(const std::filesystem::path& filename)
 {
     // First stop the music if it was already running
     stop();
 
     // Open the underlying sound file
-    if (!m_file.openFromFile(filename))
+    if (!m_impl->file.openFromFile(filename))
+    {
+        err() << "Failed to open music from file" << std::endl;
         return false;
+    }
 
     // Perform common initializations
-    initialize();
+    m_impl->initialize();
+
+    // Initialize the stream
+    SoundStream::initialize(m_impl->file.getChannelCount(), m_impl->file.getSampleRate(), m_impl->file.getChannelMap());
 
     return true;
 }
@@ -83,11 +138,17 @@ bool Music::openFromMemory(const void* data, std::size_t sizeInBytes)
     stop();
 
     // Open the underlying sound file
-    if (!m_file.openFromMemory(data, sizeInBytes))
+    if (!m_impl->file.openFromMemory(data, sizeInBytes))
+    {
+        err() << "Failed to open music from memory" << std::endl;
         return false;
+    }
 
     // Perform common initializations
-    initialize();
+    m_impl->initialize();
+
+    // Initialize the stream
+    SoundStream::initialize(m_impl->file.getChannelCount(), m_impl->file.getSampleRate(), m_impl->file.getChannelMap());
 
     return true;
 }
@@ -100,11 +161,17 @@ bool Music::openFromStream(InputStream& stream)
     stop();
 
     // Open the underlying sound file
-    if (!m_file.openFromStream(stream))
+    if (!m_impl->file.openFromStream(stream))
+    {
+        err() << "Failed to open music from stream" << std::endl;
         return false;
+    }
 
     // Perform common initializations
-    initialize();
+    m_impl->initialize();
+
+    // Initialize the stream
+    SoundStream::initialize(m_impl->file.getChannelCount(), m_impl->file.getSampleRate(), m_impl->file.getChannelMap());
 
     return true;
 }
@@ -113,26 +180,26 @@ bool Music::openFromStream(InputStream& stream)
 ////////////////////////////////////////////////////////////
 Time Music::getDuration() const
 {
-    return m_file.getDuration();
+    return m_impl->file.getDuration();
 }
 
 
 ////////////////////////////////////////////////////////////
 Music::TimeSpan Music::getLoopPoints() const
 {
-    return TimeSpan(samplesToTime(m_loopSpan.offset), samplesToTime(m_loopSpan.length));
+    return TimeSpan{samplesToTime(m_impl->loopSpan.offset), samplesToTime(m_impl->loopSpan.length)};
 }
 
 
 ////////////////////////////////////////////////////////////
 void Music::setLoopPoints(TimeSpan timePoints)
 {
-    Span<Uint64> samplePoints(timeToSamples(timePoints.offset), timeToSamples(timePoints.length));
+    Span<std::uint64_t> samplePoints{timeToSamples(timePoints.offset), timeToSamples(timePoints.length)};
 
     // Check our state. This averts a divide-by-zero. GetChannelCount() is cheap enough to use often
-    if (getChannelCount() == 0 || m_file.getSampleCount() == 0)
+    if (getChannelCount() == 0 || m_impl->file.getSampleCount() == 0)
     {
-        sf::err() << "Music is not in a valid state to assign Loop Points." << std::endl;
+        err() << "Music is not in a valid state to assign Loop Points." << std::endl;
         return;
     }
 
@@ -143,42 +210,43 @@ void Music::setLoopPoints(TimeSpan timePoints)
     samplePoints.length -= (samplePoints.length % getChannelCount());
 
     // Validate
-    if (samplePoints.offset >= m_file.getSampleCount())
+    if (samplePoints.offset >= m_impl->file.getSampleCount())
     {
-        sf::err() << "LoopPoints offset val must be in range [0, Duration)." << std::endl;
+        err() << "LoopPoints offset val must be in range [0, Duration)." << std::endl;
         return;
     }
+
     if (samplePoints.length == 0)
     {
-        sf::err() << "LoopPoints length val must be nonzero." << std::endl;
+        err() << "LoopPoints length val must be nonzero." << std::endl;
         return;
     }
 
     // Clamp End Point
-    samplePoints.length = std::min(samplePoints.length, m_file.getSampleCount() - samplePoints.offset);
+    samplePoints.length = std::min(samplePoints.length, m_impl->file.getSampleCount() - samplePoints.offset);
 
     // If this change has no effect, we can return without touching anything
-    if (samplePoints.offset == m_loopSpan.offset && samplePoints.length == m_loopSpan.length)
+    if (samplePoints.offset == m_impl->loopSpan.offset && samplePoints.length == m_impl->loopSpan.length)
         return;
 
     // When we apply this change, we need to "reset" this instance and its buffer
 
     // Get old playing status and position
-    Status oldStatus = getStatus();
-    Time oldPos = getPlayingOffset();
+    const Status oldStatus = getStatus();
+    const Time   oldPos    = getPlayingOffset();
 
     // Unload
     stop();
 
     // Set
-    m_loopSpan = samplePoints;
+    m_impl->loopSpan = samplePoints;
 
     // Restore
     if (oldPos != Time::Zero)
         setPlayingOffset(oldPos);
 
     // Resume
-    if (oldStatus == Playing)
+    if (oldStatus == Status::Playing)
         play();
 }
 
@@ -186,92 +254,83 @@ void Music::setLoopPoints(TimeSpan timePoints)
 ////////////////////////////////////////////////////////////
 bool Music::onGetData(SoundStream::Chunk& data)
 {
-    Lock lock(m_mutex);
+    const std::lock_guard lock(m_impl->mutex);
 
-    std::size_t toFill = m_samples.size();
-    Uint64 currentOffset = m_file.getSampleOffset();
-    Uint64 loopEnd = m_loopSpan.offset + m_loopSpan.length;
+    std::size_t         toFill        = m_impl->samples.size();
+    std::uint64_t       currentOffset = m_impl->file.getSampleOffset();
+    const std::uint64_t loopEnd       = m_impl->loopSpan.offset + m_impl->loopSpan.length;
 
     // If the loop end is enabled and imminent, request less data.
     // This will trip an "onLoop()" call from the underlying SoundStream,
     // and we can then take action.
-    if (getLoop() && (m_loopSpan.length != 0) && (currentOffset <= loopEnd) && (currentOffset + toFill > loopEnd))
+    if (isLooping() && (m_impl->loopSpan.length != 0) && (currentOffset <= loopEnd) && (currentOffset + toFill > loopEnd))
         toFill = static_cast<std::size_t>(loopEnd - currentOffset);
 
     // Fill the chunk parameters
-    data.samples = &m_samples[0];
-    data.sampleCount = static_cast<std::size_t>(m_file.read(&m_samples[0], toFill));
+    data.samples     = m_impl->samples.data();
+    data.sampleCount = static_cast<std::size_t>(m_impl->file.read(m_impl->samples.data(), toFill));
     currentOffset += data.sampleCount;
 
     // Check if we have stopped obtaining samples or reached either the EOF or the loop end point
-    return (data.sampleCount != 0) && (currentOffset < m_file.getSampleCount()) && !(currentOffset == loopEnd && m_loopSpan.length != 0);
+    return (data.sampleCount != 0) && (currentOffset < m_impl->file.getSampleCount()) &&
+           (currentOffset != loopEnd || m_impl->loopSpan.length == 0);
 }
 
 
 ////////////////////////////////////////////////////////////
 void Music::onSeek(Time timeOffset)
 {
-    Lock lock(m_mutex);
-    m_file.seek(timeOffset);
+    const std::lock_guard lock(m_impl->mutex);
+    m_impl->file.seek(timeOffset);
 }
 
 
 ////////////////////////////////////////////////////////////
-Int64 Music::onLoop()
+std::optional<std::uint64_t> Music::onLoop()
 {
     // Called by underlying SoundStream so we can determine where to loop.
-    Lock lock(m_mutex);
-    Uint64 currentOffset = m_file.getSampleOffset();
-    if (getLoop() && (m_loopSpan.length != 0) && (currentOffset == m_loopSpan.offset + m_loopSpan.length))
+    const std::lock_guard lock(m_impl->mutex);
+    const std::uint64_t   currentOffset = m_impl->file.getSampleOffset();
+
+    if (isLooping() && (m_impl->loopSpan.length != 0) &&
+        (currentOffset == m_impl->loopSpan.offset + m_impl->loopSpan.length))
     {
         // Looping is enabled, and either we're at the loop end, or we're at the EOF
         // when it's equivalent to the loop end (loop end takes priority). Send us to loop begin
-        m_file.seek(m_loopSpan.offset);
-        return static_cast<Int64>(m_file.getSampleOffset());
+        m_impl->file.seek(m_impl->loopSpan.offset);
+        return m_impl->file.getSampleOffset();
     }
-    else if (getLoop() && (currentOffset >= m_file.getSampleCount()))
+
+    if (isLooping() && (currentOffset >= m_impl->file.getSampleCount()))
     {
         // If we're at the EOF, reset to 0
-        m_file.seek(0);
+        m_impl->file.seek(0);
         return 0;
     }
-    return NoLoop;
+
+    return std::nullopt;
 }
 
 
 ////////////////////////////////////////////////////////////
-void Music::initialize()
-{
-    // Compute the music positions
-    m_loopSpan.offset = 0;
-    m_loopSpan.length = m_file.getSampleCount();
-
-    // Resize the internal buffer so that it can contain 1 second of audio samples
-    m_samples.resize(m_file.getSampleRate() * m_file.getChannelCount());
-
-    // Initialize the stream
-    SoundStream::initialize(m_file.getChannelCount(), m_file.getSampleRate());
-}
-
-////////////////////////////////////////////////////////////
-Uint64 Music::timeToSamples(Time position) const
+std::uint64_t Music::timeToSamples(Time position) const
 {
     // Always ROUND, no unchecked truncation, hence the addition in the numerator.
     // This avoids most precision errors arising from "samples => Time => samples" conversions
     // Original rounding calculation is ((Micros * Freq * Channels) / 1000000) + 0.5
-    // We refactor it to keep Int64 as the data type throughout the whole operation.
-    return ((static_cast<Uint64>(position.asMicroseconds()) * getSampleRate() * getChannelCount()) + 500000) / 1000000;
+    // We refactor it to keep std::int64_t as the data type throughout the whole operation.
+    return ((static_cast<std::uint64_t>(position.asMicroseconds()) * getSampleRate() * getChannelCount()) + 500000) / 1000000;
 }
 
 
 ////////////////////////////////////////////////////////////
-Time Music::samplesToTime(Uint64 samples) const
+Time Music::samplesToTime(std::uint64_t samples) const
 {
     Time position = Time::Zero;
 
     // Make sure we don't divide by 0
     if (getSampleRate() != 0 && getChannelCount() != 0)
-        position = microseconds(static_cast<Int64>((samples * 1000000) / (getChannelCount() * getSampleRate())));
+        position = microseconds(static_cast<std::int64_t>((samples * 1000000) / (getChannelCount() * getSampleRate())));
 
     return position;
 }
