@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,20 +26,19 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Graphics/RectangleShape.hpp>
-#include <cmath>
 
 
 namespace sf
 {
 ////////////////////////////////////////////////////////////
-RectangleShape::RectangleShape(const Vector2f& size)
+RectangleShape::RectangleShape(Vector2f size)
 {
     setSize(size);
 }
 
 
 ////////////////////////////////////////////////////////////
-void RectangleShape::setSize(const Vector2f& size)
+void RectangleShape::setSize(Vector2f size)
 {
     m_size = size;
     update();
@@ -47,7 +46,7 @@ void RectangleShape::setSize(const Vector2f& size)
 
 
 ////////////////////////////////////////////////////////////
-const Vector2f& RectangleShape::getSize() const
+Vector2f RectangleShape::getSize() const
 {
     return m_size;
 }
@@ -66,11 +65,22 @@ Vector2f RectangleShape::getPoint(std::size_t index) const
     switch (index)
     {
         default:
-        case 0: return Vector2f(0, 0);
-        case 1: return Vector2f(m_size.x, 0);
-        case 2: return Vector2f(m_size.x, m_size.y);
-        case 3: return Vector2f(0, m_size.y);
+        case 0:
+            return {0, 0};
+        case 1:
+            return {m_size.x, 0};
+        case 2:
+            return {m_size.x, m_size.y};
+        case 3:
+            return {0, m_size.y};
     }
 }
 
+
+////////////////////////////////////////////////////////////
+Vector2f RectangleShape::getGeometricCenter() const
+{
+    return m_size / 2.f;
+}
+
 } // namespace sf
