@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,18 +22,15 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_TEXTURESAVER_HPP
-#define SFML_TEXTURESAVER_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
-#include <SFML/Graphics/GLCheck.hpp>
+#include <SFML/Graphics/GLExtensions.hpp>
 
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
 /// \brief Automatic wrapper for saving and restoring the current texture binding
@@ -42,7 +39,6 @@ namespace priv
 class TextureSaver
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Default constructor
     ///
@@ -60,16 +56,10 @@ public:
     ~TextureSaver();
 
 private:
-
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    GLint m_textureBinding; //!< Texture binding to restore
+    GLint m_textureBinding{}; //!< Texture binding to restore
 };
 
-} // namespace priv
-
-} // namespace sf
-
-
-#endif // SFML_TEXTURESAVER_HPP
+} // namespace sf::priv
