@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,60 +25,81 @@
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
-#include <SFML/Network/IpAddress.hpp>
 #include <SFML/Network/Http.hpp>
+#include <SFML/Network/IpAddress.hpp>
 #include <SFML/Network/SocketImpl.hpp>
+
+#include <SFML/System/Err.hpp>
+
+#include <istream>
+#include <ostream>
+
 #include <cstring>
-#include <utility>
 
 
 namespace sf
 {
 ////////////////////////////////////////////////////////////
-const IpAddress IpAddress::None;
 const IpAddress IpAddress::Any(0, 0, 0, 0);
 const IpAddress IpAddress::LocalHost(127, 0, 0, 1);
 const IpAddress IpAddress::Broadcast(255, 255, 255, 255);
 
 
 ////////////////////////////////////////////////////////////
-IpAddress::IpAddress() :
-m_address(0),
-m_valid  (false)
+std::optional<IpAddress> IpAddress::resolve(std::string_view address)
+{
+    using namespace std::string_view_literals;
+
+    if (address.empty())
+    {
+        // Not generating en error message here as resolution failure is a valid outcome.
+        return std::nullopt;
+    }
+
+    if (address == "255.255.255.255"sv)
+    {
+        // The broadcast address needs to be handled explicitly,
+        // because it is also the value returned by inet_addr on error
+        return Broadcast;
+    }
+
+    if (address == "0.0.0.0"sv)
+        return Any;
+
+    // Try to convert the address as a byte representation ("xxx.xxx.xxx.xxx")
+    if (const std::uint32_t ip = inet_addr(address.data()); ip != INADDR_NONE)
+        return IpAddress(ntohl(ip));
+
+    // Not a valid address, try to convert it as a host name
+    addrinfo hints{}; // Zero-initialize
+    hints.ai_family = AF_INET;
+
+    addrinfo* result = nullptr;
+    if (getaddrinfo(address.data(), nullptr, &hints, &result) == 0 && result != nullptr)
+    {
+        sockaddr_in sin{};
+        std::memcpy(&sin, result->ai_addr, sizeof(*result->ai_addr));
+
+        const std::uint32_t ip = sin.sin_addr.s_addr;
+        freeaddrinfo(result);
+
+        return IpAddress(ntohl(ip));
+    }
+
+    // Not generating en error message here as resolution failure is a valid outcome.
+    return std::nullopt;
+}
+
+
+////////////////////////////////////////////////////////////
+IpAddress::IpAddress(std::uint8_t byte0, std::uint8_t byte1, std::uint8_t byte2, std::uint8_t byte3) :
+m_address(static_cast<std::uint32_t>((byte0 << 24) | (byte1 << 16) | (byte2 << 8) | byte3))
 {
 }
 
 
 ////////////////////////////////////////////////////////////
-IpAddress::IpAddress(const std::string& address) :
-m_address(0),
-m_valid  (false)
-{
-    resolve(address);
-}
-
-
-////////////////////////////////////////////////////////////
-IpAddress::IpAddress(const char* address) :
-m_address(0),
-m_valid  (false)
-{
-    resolve(address);
-}
-
-
-////////////////////////////////////////////////////////////
-IpAddress::IpAddress(Uint8 byte0, Uint8 byte1, Uint8 byte2, Uint8 byte3) :
-m_address(htonl(static_cast<Uint32>((byte0 << 24) | (byte1 << 16) | (byte2 << 8) | byte3))),
-m_valid  (true)
-{
-}
-
-
-////////////////////////////////////////////////////////////
-IpAddress::IpAddress(Uint32 address) :
-m_address(htonl(address)),
-m_valid  (true)
+IpAddress::IpAddress(std::uint32_t address) : m_address(address)
 {
 }
 
@@ -86,40 +107,45 @@ m_valid  (true)
 ////////////////////////////////////////////////////////////
 std::string IpAddress::toString() const
 {
-    in_addr address;
-    address.s_addr = m_address;
+    in_addr address{};
+    address.s_addr = htonl(m_address);
 
     return inet_ntoa(address);
 }
 
 
 ////////////////////////////////////////////////////////////
-Uint32 IpAddress::toInteger() const
+std::uint32_t IpAddress::toInteger() const
 {
-    return ntohl(m_address);
+    return m_address;
 }
 
 
 ////////////////////////////////////////////////////////////
-IpAddress IpAddress::getLocalAddress()
+std::optional<IpAddress> IpAddress::getLocalAddress()
 {
-    // The method here is to connect a UDP socket to anyone (here to localhost),
+    // The method here is to connect a UDP socket to a public ip,
     // and get the local socket address with the getsockname function.
     // UDP connection will not send anything to the network, so this function won't cause any overhead.
 
-    IpAddress localAddress;
-
     // Create the socket
-    SocketHandle sock = socket(PF_INET, SOCK_DGRAM, 0);
+    const SocketHandle sock = socket(PF_INET, SOCK_DGRAM, 0);
     if (sock == priv::SocketImpl::invalidSocket())
-        return localAddress;
+    {
+        err() << "Failed to retrieve local address (invalid socket)" << std::endl;
+        return std::nullopt;
+    }
 
-    // Connect the socket to localhost on any port
-    sockaddr_in address = priv::SocketImpl::createAddress(ntohl(INADDR_LOOPBACK), 9);
+    // Connect the socket to a public ip (here 1.1.1.1) on any
+    // port. This will give the local address of the network interface
+    // used for default routing which is usually what we want.
+    sockaddr_in address = priv::SocketImpl::createAddress(0x01010101, 9);
     if (connect(sock, reinterpret_cast<sockaddr*>(&address), sizeof(address)) == -1)
     {
         priv::SocketImpl::close(sock);
-        return localAddress;
+
+        err() << "Failed to retrieve local address (socket connection failure)" << std::endl;
+        return std::nullopt;
     }
 
     // Get the local address of the socket connection
@@ -127,21 +153,21 @@ IpAddress IpAddress::getLocalAddress()
     if (getsockname(sock, reinterpret_cast<sockaddr*>(&address), &size) == -1)
     {
         priv::SocketImpl::close(sock);
-        return localAddress;
+
+        err() << "Failed to retrieve local address (socket local address retrieval failure)" << std::endl;
+        return std::nullopt;
     }
 
     // Close the socket
     priv::SocketImpl::close(sock);
 
     // Finally build the IP address
-    localAddress = IpAddress(ntohl(address.sin_addr.s_addr));
-
-    return localAddress;
+    return IpAddress(ntohl(address.sin_addr.s_addr));
 }
 
 
 ////////////////////////////////////////////////////////////
-IpAddress IpAddress::getPublicAddress(Time timeout)
+std::optional<IpAddress> IpAddress::getPublicAddress(Time timeout)
 {
     // The trick here is more complicated, because the only way
     // to get our public IP address is to get it from a distant computer.
@@ -149,123 +175,77 @@ IpAddress IpAddress::getPublicAddress(Time timeout)
     // and parse the result to extract our IP address
     // (not very hard: the web page contains only our IP address).
 
-    Http server("www.sfml-dev.org");
-    Http::Request request("/ip-provider.php", Http::Request::Get);
-    Http::Response page = server.sendRequest(request, timeout);
-    if (page.getStatus() == Http::Response::Ok)
-        return IpAddress(page.getBody());
+    Http                 server("www.sfml-dev.org");
+    const Http::Request  request("/ip-provider.php", Http::Request::Method::Get);
+    const Http::Response page = server.sendRequest(request, timeout);
 
-    // Something failed: return an invalid address
-    return IpAddress();
+    const Http::Response::Status status = page.getStatus();
+
+    if (status == Http::Response::Status::Ok)
+        return IpAddress::resolve(page.getBody());
+
+    err() << "Failed to retrieve public address from external IP resolution server (HTTP response status "
+          << static_cast<int>(status) << ")" << std::endl;
+
+    return std::nullopt;
 }
 
 
 ////////////////////////////////////////////////////////////
-void IpAddress::resolve(const std::string& address)
-{
-    m_address = 0;
-    m_valid = false;
-
-    if (address == "255.255.255.255")
-    {
-        // The broadcast address needs to be handled explicitly,
-        // because it is also the value returned by inet_addr on error
-        m_address = INADDR_BROADCAST;
-        m_valid = true;
-    }
-    else if (address == "0.0.0.0")
-    {
-        m_address = INADDR_ANY;
-        m_valid = true;
-    }
-    else
-    {
-        // Try to convert the address as a byte representation ("xxx.xxx.xxx.xxx")
-        Uint32 ip = inet_addr(address.c_str());
-        if (ip != INADDR_NONE)
-        {
-            m_address = ip;
-            m_valid = true;
-        }
-        else
-        {
-            // Not a valid address, try to convert it as a host name
-            addrinfo hints;
-            std::memset(&hints, 0, sizeof(hints));
-            hints.ai_family = AF_INET;
-            addrinfo* result = NULL;
-            if (getaddrinfo(address.c_str(), NULL, &hints, &result) == 0)
-            {
-                if (result)
-                {
-                    sockaddr_in sin;
-                    std::memcpy(&sin, result->ai_addr, sizeof(*result->ai_addr));
-                    ip = sin.sin_addr.s_addr;
-                    freeaddrinfo(result);
-                    m_address = ip;
-                    m_valid = true;
-                }
-            }
-        }
-    }
-}
-
-
-////////////////////////////////////////////////////////////
-bool operator ==(const IpAddress& left, const IpAddress& right)
+bool operator==(IpAddress left, IpAddress right)
 {
     return !(left < right) && !(right < left);
 }
 
 
 ////////////////////////////////////////////////////////////
-bool operator !=(const IpAddress& left, const IpAddress& right)
+bool operator!=(IpAddress left, IpAddress right)
 {
     return !(left == right);
 }
 
 
 ////////////////////////////////////////////////////////////
-bool operator <(const IpAddress& left, const IpAddress& right)
+bool operator<(IpAddress left, IpAddress right)
 {
-    return std::make_pair(left.m_valid, left.m_address) < std::make_pair(right.m_valid, right.m_address);
+    return left.m_address < right.m_address;
 }
 
 
 ////////////////////////////////////////////////////////////
-bool operator >(const IpAddress& left, const IpAddress& right)
+bool operator>(IpAddress left, IpAddress right)
 {
     return right < left;
 }
 
 
 ////////////////////////////////////////////////////////////
-bool operator <=(const IpAddress& left, const IpAddress& right)
+bool operator<=(IpAddress left, IpAddress right)
 {
     return !(right < left);
 }
 
 
 ////////////////////////////////////////////////////////////
-bool operator >=(const IpAddress& left, const IpAddress& right)
+bool operator>=(IpAddress left, IpAddress right)
 {
     return !(left < right);
 }
 
 
 ////////////////////////////////////////////////////////////
-std::istream& operator >>(std::istream& stream, IpAddress& address)
+std::istream& operator>>(std::istream& stream, std::optional<IpAddress>& address)
 {
     std::string str;
     stream >> str;
-    address = IpAddress(str);
+    address = IpAddress::resolve(str);
 
     return stream;
 }
 
 
 ////////////////////////////////////////////////////////////
-std::ostream& operator <<(std::ostream& stream, const IpAddress& address)
+std::ostream& operator<<(std::ostream& stream, IpAddress address)
 {
     return stream << address.toString();
 }
