@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,38 +27,27 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Network/Packet.hpp>
 #include <SFML/Network/SocketImpl.hpp>
+
 #include <SFML/System/String.hpp>
+#include <SFML/System/Utils.hpp>
+
+#include <array>
+
+#include <cassert>
 #include <cstring>
 #include <cwchar>
 
 
 namespace sf
 {
-////////////////////////////////////////////////////////////
-Packet::Packet() :
-m_readPos(0),
-m_sendPos(0),
-m_isValid(true)
-{
-
-}
-
-
-////////////////////////////////////////////////////////////
-Packet::~Packet()
-{
-
-}
-
-
 ////////////////////////////////////////////////////////////
 void Packet::append(const void* data, std::size_t sizeInBytes)
 {
     if (data && (sizeInBytes > 0))
     {
-        std::size_t start = m_data.size();
-        m_data.resize(start + sizeInBytes);
-        std::memcpy(&m_data[start], data, sizeInBytes);
+        const auto* begin = reinterpret_cast<const std::byte*>(data);
+        const auto* end   = begin + sizeInBytes;
+        m_data.insert(m_data.end(), begin, end);
     }
 }
 
@@ -82,7 +71,7 @@ void Packet::clear()
 ////////////////////////////////////////////////////////////
 const void* Packet::getData() const
 {
-    return !m_data.empty() ? &m_data[0] : NULL;
+    return !m_data.empty() ? m_data.data() : nullptr;
 }
 
 
@@ -101,16 +90,16 @@ bool Packet::endOfPacket() const
 
 
 ////////////////////////////////////////////////////////////
-Packet::operator BoolType() const
+Packet::operator bool() const
 {
-    return m_isValid ? &Packet::checkSize : NULL;
+    return m_isValid;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(bool& data)
+Packet& Packet::operator>>(bool& data)
 {
-    Uint8 value;
+    std::uint8_t value = 0;
     if (*this >> value)
         data = (value != 0);
 
@@ -119,7 +108,7 @@ Packet& Packet::operator >>(bool& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Int8& data)
+Packet& Packet::operator>>(std::int8_t& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -132,7 +121,7 @@ Packet& Packet::operator >>(Int8& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Uint8& data)
+Packet& Packet::operator>>(std::uint8_t& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -145,12 +134,12 @@ Packet& Packet::operator >>(Uint8& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Int16& data)
+Packet& Packet::operator>>(std::int16_t& data)
 {
     if (checkSize(sizeof(data)))
     {
         std::memcpy(&data, &m_data[m_readPos], sizeof(data));
-        data = static_cast<Int16>(ntohs(static_cast<Uint16>(data)));
+        data = static_cast<std::int16_t>(ntohs(static_cast<std::uint16_t>(data)));
         m_readPos += sizeof(data);
     }
 
@@ -159,7 +148,7 @@ Packet& Packet::operator >>(Int16& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Uint16& data)
+Packet& Packet::operator>>(std::uint16_t& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -173,12 +162,12 @@ Packet& Packet::operator >>(Uint16& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Int32& data)
+Packet& Packet::operator>>(std::int32_t& data)
 {
     if (checkSize(sizeof(data)))
     {
         std::memcpy(&data, &m_data[m_readPos], sizeof(data));
-        data = static_cast<Int32>(ntohl(static_cast<Uint32>(data)));
+        data = static_cast<std::int32_t>(ntohl(static_cast<std::uint32_t>(data)));
         m_readPos += sizeof(data);
     }
 
@@ -187,7 +176,7 @@ Packet& Packet::operator >>(Int32& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Uint32& data)
+Packet& Packet::operator>>(std::uint32_t& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -201,22 +190,17 @@ Packet& Packet::operator >>(Uint32& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Int64& data)
+Packet& Packet::operator>>(std::int64_t& data)
 {
     if (checkSize(sizeof(data)))
     {
         // Since ntohll is not available everywhere, we have to convert
         // to network byte order (big endian) manually
-        Uint8 bytes[sizeof(data)];
-        std::memcpy(bytes, &m_data[m_readPos], sizeof(data));
-        data = (static_cast<Int64>(bytes[0]) << 56) |
-               (static_cast<Int64>(bytes[1]) << 48) |
-               (static_cast<Int64>(bytes[2]) << 40) |
-               (static_cast<Int64>(bytes[3]) << 32) |
-               (static_cast<Int64>(bytes[4]) << 24) |
-               (static_cast<Int64>(bytes[5]) << 16) |
-               (static_cast<Int64>(bytes[6]) <<  8) |
-               (static_cast<Int64>(bytes[7])      );
+        std::array<std::byte, sizeof(data)> bytes{};
+        std::memcpy(bytes.data(), &m_data[m_readPos], bytes.size());
+
+        data = toInteger<std::int64_t>(bytes[7], bytes[6], bytes[5], bytes[4], bytes[3], bytes[2], bytes[1], bytes[0]);
+
         m_readPos += sizeof(data);
     }
 
@@ -225,22 +209,17 @@ Packet& Packet::operator >>(Int64& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(Uint64& data)
+Packet& Packet::operator>>(std::uint64_t& data)
 {
     if (checkSize(sizeof(data)))
     {
         // Since ntohll is not available everywhere, we have to convert
         // to network byte order (big endian) manually
-        Uint8 bytes[sizeof(data)];
-        std::memcpy(bytes, &m_data[m_readPos], sizeof(data));
-        data = (static_cast<Uint64>(bytes[0]) << 56) |
-               (static_cast<Uint64>(bytes[1]) << 48) |
-               (static_cast<Uint64>(bytes[2]) << 40) |
-               (static_cast<Uint64>(bytes[3]) << 32) |
-               (static_cast<Uint64>(bytes[4]) << 24) |
-               (static_cast<Uint64>(bytes[5]) << 16) |
-               (static_cast<Uint64>(bytes[6]) <<  8) |
-               (static_cast<Uint64>(bytes[7])      );
+        std::array<std::byte, sizeof(data)> bytes{};
+        std::memcpy(bytes.data(), &m_data[m_readPos], sizeof(data));
+
+        data = toInteger<std::uint64_t>(bytes[7], bytes[6], bytes[5], bytes[4], bytes[3], bytes[2], bytes[1], bytes[0]);
+
         m_readPos += sizeof(data);
     }
 
@@ -249,7 +228,7 @@ Packet& Packet::operator >>(Uint64& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(float& data)
+Packet& Packet::operator>>(float& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -262,7 +241,7 @@ Packet& Packet::operator >>(float& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(double& data)
+Packet& Packet::operator>>(double& data)
 {
     if (checkSize(sizeof(data)))
     {
@@ -275,10 +254,12 @@ Packet& Packet::operator >>(double& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(char* data)
+Packet& Packet::operator>>(char* data)
 {
+    assert(data && "Packet::operator>> Data must not be null");
+
     // First extract string length
-    Uint32 length = 0;
+    std::uint32_t length = 0;
     *this >> length;
 
     if ((length > 0) && checkSize(length))
@@ -296,17 +277,17 @@ Packet& Packet::operator >>(char* data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(std::string& data)
+Packet& Packet::operator>>(std::string& data)
 {
     // First extract string length
-    Uint32 length = 0;
+    std::uint32_t length = 0;
     *this >> length;
 
     data.clear();
     if ((length > 0) && checkSize(length))
     {
         // Then extract characters
-        data.assign(&m_data[m_readPos], length);
+        data.assign(reinterpret_cast<char*>(&m_data[m_readPos]), length);
 
         // Update reading position
         m_readPos += length;
@@ -317,18 +298,20 @@ Packet& Packet::operator >>(std::string& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(wchar_t* data)
+Packet& Packet::operator>>(wchar_t* data)
 {
+    assert(data && "Packet::operator>> Data must not be null");
+
     // First extract string length
-    Uint32 length = 0;
+    std::uint32_t length = 0;
     *this >> length;
 
-    if ((length > 0) && checkSize(length * sizeof(Uint32)))
+    if ((length > 0) && checkSize(length * sizeof(std::uint32_t)))
     {
         // Then extract characters
-        for (Uint32 i = 0; i < length; ++i)
+        for (std::uint32_t i = 0; i < length; ++i)
         {
-            Uint32 character = 0;
+            std::uint32_t character = 0;
             *this >> character;
             data[i] = static_cast<wchar_t>(character);
         }
@@ -340,19 +323,19 @@ Packet& Packet::operator >>(wchar_t* data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(std::wstring& data)
+Packet& Packet::operator>>(std::wstring& data)
 {
     // First extract string length
-    Uint32 length = 0;
+    std::uint32_t length = 0;
     *this >> length;
 
     data.clear();
-    if ((length > 0) && checkSize(length * sizeof(Uint32)))
+    if ((length > 0) && checkSize(length * sizeof(std::uint32_t)))
     {
         // Then extract characters
-        for (Uint32 i = 0; i < length; ++i)
+        for (std::uint32_t i = 0; i < length; ++i)
         {
-            Uint32 character = 0;
+            std::uint32_t character = 0;
             *this >> character;
             data += static_cast<wchar_t>(character);
         }
@@ -363,21 +346,21 @@ Packet& Packet::operator >>(std::wstring& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator >>(String& data)
+Packet& Packet::operator>>(String& data)
 {
     // First extract the string length
-    Uint32 length = 0;
+    std::uint32_t length = 0;
     *this >> length;
 
     data.clear();
-    if ((length > 0) && checkSize(length * sizeof(Uint32)))
+    if ((length > 0) && checkSize(length * sizeof(std::uint32_t)))
     {
         // Then extract characters
-        for (Uint32 i = 0; i < length; ++i)
+        for (std::uint32_t i = 0; i < length; ++i)
         {
-            Uint32 character = 0;
+            std::uint32_t character = 0;
             *this >> character;
-            data += character;
+            data += static_cast<char32_t>(character);
         }
     }
 
@@ -386,15 +369,15 @@ Packet& Packet::operator >>(String& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(bool data)
+Packet& Packet::operator<<(bool data)
 {
-    *this << static_cast<Uint8>(data);
+    *this << static_cast<std::uint8_t>(data);
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Int8 data)
+Packet& Packet::operator<<(std::int8_t data)
 {
     append(&data, sizeof(data));
     return *this;
@@ -402,7 +385,7 @@ Packet& Packet::operator <<(Int8 data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Uint8 data)
+Packet& Packet::operator<<(std::uint8_t data)
 {
     append(&data, sizeof(data));
     return *this;
@@ -410,85 +393,83 @@ Packet& Packet::operator <<(Uint8 data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Int16 data)
+Packet& Packet::operator<<(std::int16_t data)
 {
-    Int16 toWrite = static_cast<Int16>(htons(static_cast<Uint16>(data)));
+    const auto toWrite = static_cast<std::int16_t>(htons(static_cast<std::uint16_t>(data)));
     append(&toWrite, sizeof(toWrite));
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Uint16 data)
+Packet& Packet::operator<<(std::uint16_t data)
 {
-    Uint16 toWrite = htons(data);
+    const std::uint16_t toWrite = htons(data);
     append(&toWrite, sizeof(toWrite));
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Int32 data)
+Packet& Packet::operator<<(std::int32_t data)
 {
-    Int32 toWrite = static_cast<Int32>(htonl(static_cast<Uint32>(data)));
+    const auto toWrite = static_cast<std::int32_t>(htonl(static_cast<std::uint32_t>(data)));
     append(&toWrite, sizeof(toWrite));
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Uint32 data)
+Packet& Packet::operator<<(std::uint32_t data)
 {
-    Uint32 toWrite = htonl(data);
+    const std::uint32_t toWrite = htonl(data);
     append(&toWrite, sizeof(toWrite));
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Int64 data)
+Packet& Packet::operator<<(std::int64_t data)
 {
     // Since htonll is not available everywhere, we have to convert
     // to network byte order (big endian) manually
-    Uint8 toWrite[] =
-    {
-        static_cast<Uint8>((data >> 56) & 0xFF),
-        static_cast<Uint8>((data >> 48) & 0xFF),
-        static_cast<Uint8>((data >> 40) & 0xFF),
-        static_cast<Uint8>((data >> 32) & 0xFF),
-        static_cast<Uint8>((data >> 24) & 0xFF),
-        static_cast<Uint8>((data >> 16) & 0xFF),
-        static_cast<Uint8>((data >>  8) & 0xFF),
-        static_cast<Uint8>((data      ) & 0xFF)
-    };
-    append(&toWrite, sizeof(toWrite));
+
+    const std::array toWrite = {static_cast<std::uint8_t>((data >> 56) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 48) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 40) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 32) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 24) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 16) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 8) & 0xFF),
+                                static_cast<std::uint8_t>((data) & 0xFF)};
+
+    append(toWrite.data(), toWrite.size());
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(Uint64 data)
+Packet& Packet::operator<<(std::uint64_t data)
 {
     // Since htonll is not available everywhere, we have to convert
     // to network byte order (big endian) manually
-    Uint8 toWrite[] =
-    {
-        static_cast<Uint8>((data >> 56) & 0xFF),
-        static_cast<Uint8>((data >> 48) & 0xFF),
-        static_cast<Uint8>((data >> 40) & 0xFF),
-        static_cast<Uint8>((data >> 32) & 0xFF),
-        static_cast<Uint8>((data >> 24) & 0xFF),
-        static_cast<Uint8>((data >> 16) & 0xFF),
-        static_cast<Uint8>((data >>  8) & 0xFF),
-        static_cast<Uint8>((data      ) & 0xFF)
-    };
-    append(&toWrite, sizeof(toWrite));
+
+    const std::array toWrite = {static_cast<std::uint8_t>((data >> 56) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 48) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 40) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 32) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 24) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 16) & 0xFF),
+                                static_cast<std::uint8_t>((data >> 8) & 0xFF),
+                                static_cast<std::uint8_t>((data) & 0xFF)};
+
+    append(toWrite.data(), toWrite.size());
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(float data)
+Packet& Packet::operator<<(float data)
 {
     append(&data, sizeof(data));
     return *this;
@@ -496,7 +477,7 @@ Packet& Packet::operator <<(float data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(double data)
+Packet& Packet::operator<<(double data)
 {
     append(&data, sizeof(data));
     return *this;
@@ -504,10 +485,12 @@ Packet& Packet::operator <<(double data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(const char* data)
+Packet& Packet::operator<<(const char* data)
 {
+    assert(data && "Packet::operator<< Data must not be null");
+
     // First insert string length
-    Uint32 length = static_cast<Uint32>(std::strlen(data));
+    const auto length = static_cast<std::uint32_t>(std::strlen(data));
     *this << length;
 
     // Then insert characters
@@ -518,10 +501,10 @@ Packet& Packet::operator <<(const char* data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(const std::string& data)
+Packet& Packet::operator<<(const std::string& data)
 {
     // First insert string length
-    Uint32 length = static_cast<Uint32>(data.size());
+    const auto length = static_cast<std::uint32_t>(data.size());
     *this << length;
 
     // Then insert characters
@@ -533,32 +516,34 @@ Packet& Packet::operator <<(const std::string& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(const wchar_t* data)
+Packet& Packet::operator<<(const wchar_t* data)
 {
+    assert(data && "Packet::operator<< Data must not be null");
+
     // First insert string length
-    Uint32 length = static_cast<Uint32>(std::wcslen(data));
+    const auto length = static_cast<std::uint32_t>(std::wcslen(data));
     *this << length;
 
     // Then insert characters
     for (const wchar_t* c = data; *c != L'\0'; ++c)
-        *this << static_cast<Uint32>(*c);
+        *this << static_cast<std::uint32_t>(*c);
 
     return *this;
 }
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(const std::wstring& data)
+Packet& Packet::operator<<(const std::wstring& data)
 {
     // First insert string length
-    Uint32 length = static_cast<Uint32>(data.size());
+    const auto length = static_cast<std::uint32_t>(data.size());
     *this << length;
 
     // Then insert characters
     if (length > 0)
     {
-        for (std::wstring::const_iterator c = data.begin(); c != data.end(); ++c)
-            *this << static_cast<Uint32>(*c);
+        for (const wchar_t c : data)
+            *this << static_cast<std::uint32_t>(c);
     }
 
     return *this;
@@ -566,17 +551,17 @@ Packet& Packet::operator <<(const std::wstring& data)
 
 
 ////////////////////////////////////////////////////////////
-Packet& Packet::operator <<(const String& data)
+Packet& Packet::operator<<(const String& data)
 {
     // First insert the string length
-    Uint32 length = static_cast<Uint32>(data.getSize());
+    const auto length = static_cast<std::uint32_t>(data.getSize());
     *this << length;
 
     // Then insert characters
     if (length > 0)
     {
-        for (String::ConstIterator c = data.begin(); c != data.end(); ++c)
-            *this << *c;
+        for (const unsigned int datum : data)
+            *this << datum;
     }
 
     return *this;
@@ -586,7 +571,9 @@ Packet& Packet::operator <<(const String& data)
 ////////////////////////////////////////////////////////////
 bool Packet::checkSize(std::size_t size)
 {
-    m_isValid = m_isValid && (m_readPos + size <= m_data.size());
+    // Determine if size is big enough to trigger an overflow
+    const bool overflowDetected = m_readPos + size < m_readPos;
+    m_isValid                   = m_isValid && (m_readPos + size <= m_data.size()) && !overflowDetected;
 
     return m_isValid;
 }
