@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,22 +25,22 @@
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
-#include <SFML/Network/Unix/SocketImpl.hpp>
+#include <SFML/Network/SocketImpl.hpp>
+
 #include <SFML/System/Err.hpp>
-#include <errno.h>
+
 #include <fcntl.h>
-#include <cstring>
+#include <ostream>
+
+#include <cerrno>
 
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
-sockaddr_in SocketImpl::createAddress(Uint32 address, unsigned short port)
+sockaddr_in SocketImpl::createAddress(std::uint32_t address, unsigned short port)
 {
-    sockaddr_in addr;
-    std::memset(&addr, 0, sizeof(addr));
+    auto addr            = sockaddr_in();
     addr.sin_addr.s_addr = htonl(address);
     addr.sin_family      = AF_INET;
     addr.sin_port        = htons(port);
@@ -70,7 +70,7 @@ void SocketImpl::close(SocketHandle sock)
 ////////////////////////////////////////////////////////////
 void SocketImpl::setBlocking(SocketHandle sock, bool block)
 {
-    int status = fcntl(sock, F_GETFL);
+    const int status = fcntl(sock, F_GETFL);
     if (block)
     {
         if (fcntl(sock, F_SETFL, status & ~O_NONBLOCK) == -1)
@@ -80,7 +80,6 @@ void SocketImpl::setBlocking(SocketHandle sock, bool block)
     {
         if (fcntl(sock, F_SETFL, status | O_NONBLOCK) == -1)
             err() << "Failed to set file status flags: " << errno << std::endl;
-
     }
 }
 
@@ -88,25 +87,25 @@ void SocketImpl::setBlocking(SocketHandle sock, bool block)
 ////////////////////////////////////////////////////////////
 Socket::Status SocketImpl::getErrorStatus()
 {
-    // The followings are sometimes equal to EWOULDBLOCK,
+    // The following are sometimes equal to EWOULDBLOCK,
     // so we have to make a special case for them in order
     // to avoid having double values in the switch case
     if ((errno == EAGAIN) || (errno == EINPROGRESS))
-        return Socket::NotReady;
+        return Socket::Status::NotReady;
 
+    // clang-format off
     switch (errno)
     {
-        case EWOULDBLOCK:  return Socket::NotReady;
-        case ECONNABORTED: return Socket::Disconnected;
-        case ECONNRESET:   return Socket::Disconnected;
-        case ETIMEDOUT:    return Socket::Disconnected;
-        case ENETRESET:    return Socket::Disconnected;
-        case ENOTCONN:     return Socket::Disconnected;
-        case EPIPE:        return Socket::Disconnected;
-        default:           return Socket::Error;
+        case EWOULDBLOCK:  return Socket::Status::NotReady;
+        case ECONNABORTED: return Socket::Status::Disconnected;
+        case ECONNRESET:   return Socket::Status::Disconnected;
+        case ETIMEDOUT:    return Socket::Status::Disconnected;
+        case ENETRESET:    return Socket::Status::Disconnected;
+        case ENOTCONN:     return Socket::Status::Disconnected;
+        case EPIPE:        return Socket::Status::Disconnected;
+        default:           return Socket::Status::Error;
     }
+    // clang-format on
 }
 
-} // namespace priv
-
-} // namespace sf
+} // namespace sf::priv
