@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,10 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/System/Err.hpp>
+
+#include <iostream>
 #include <streambuf>
+
 #include <cstdio>
 
 
@@ -37,16 +40,15 @@ namespace
 class DefaultErrStreamBuf : public std::streambuf
 {
 public:
-
     DefaultErrStreamBuf()
     {
         // Allocate the write buffer
-        static const int size = 64;
-        char* buffer = new char[size];
+        constexpr int size   = 64;
+        char*         buffer = new char[size];
         setp(buffer, buffer + size);
     }
 
-    ~DefaultErrStreamBuf()
+    ~DefaultErrStreamBuf() override
     {
         // Synchronize
         sync();
@@ -56,35 +58,32 @@ public:
     }
 
 private:
-
-    virtual int overflow(int character)
+    int overflow(int character) override
     {
         if ((character != EOF) && (pptr() != epptr()))
         {
             // Valid character
             return sputc(static_cast<char>(character));
         }
-        else if (character != EOF)
+        if (character != EOF)
         {
             // Not enough space in the buffer: synchronize output and try again
             sync();
             return overflow(character);
         }
-        else
-        {
-            // Invalid character: synchronize output
-            return sync();
-        }
+
+        // Invalid character: synchronize output
+        return sync();
     }
 
-    virtual int sync()
+    int sync() override
     {
         // Check if there is something into the write buffer
         if (pbase() != pptr())
         {
             // Print the contents of the write buffer into the standard error output
-            std::size_t size = static_cast<std::size_t>(pptr() - pbase());
-            fwrite(pbase(), 1, size, stderr);
+            const auto size = static_cast<std::size_t>(pptr() - pbase());
+            std::fwrite(pbase(), 1, size, stderr);
 
             // Reset the pointer position to the beginning of the write buffer
             setp(pbase(), epptr());
@@ -93,7 +92,7 @@ private:
         return 0;
     }
 };
-}
+} // namespace
 
 namespace sf
 {
@@ -101,7 +100,7 @@ namespace sf
 std::ostream& err()
 {
     static DefaultErrStreamBuf buffer;
-    static std::ostream stream(&buffer);
+    static std::ostream        stream(&buffer);
 
     return stream;
 }
