@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,27 +26,27 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Android/ClipboardImpl.hpp>
+
 #include <SFML/System/Err.hpp>
+#include <SFML/System/String.hpp>
+
+#include <ostream>
 
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
 String ClipboardImpl::getString()
 {
-    sf::err() << "Clipboard API not implemented for Android.\n";
-    return String();
+    err() << "Clipboard API not implemented for Android.\n";
+    return {};
 }
 
 
 ////////////////////////////////////////////////////////////
 void ClipboardImpl::setString(const String& /* text */)
 {
-    sf::err() << "Clipboard API not implemented for Android.\n";
+    err() << "Clipboard API not implemented for Android.\n";
 }
 
-} // namespace priv
-
-} // namespace sf
+} // namespace sf::priv
