@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,13 +26,16 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/SensorImpl.hpp>
+
+#include <SFML/System/EnumArray.hpp>
 #include <SFML/System/Time.hpp>
+
 #include <android/looper.h>
 
-#if defined(__clang__)
-    #pragma clang diagnostic ignored "-Wdeprecated-declarations"
-#elif defined(__GNUC__)
-    #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#include <optional>
+
+#if defined(__clang__) || defined(__GNUC__)
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
 // Define missing constants
@@ -42,16 +45,14 @@
 
 namespace
 {
-    ALooper* looper;
-    ASensorManager*    sensorManager;
-    ASensorEventQueue* sensorEventQueue;
-    sf::Vector3f       sensorData[sf::Sensor::Count];
-}
+ALooper*                                                               looper;
+ASensorManager*                                                        sensorManager;
+ASensorEventQueue*                                                     sensorEventQueue;
+sf::priv::EnumArray<sf::Sensor::Type, sf::Vector3f, sf::Sensor::Count> sensorData;
+} // namespace
 
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
 void SensorImpl::initialize()
@@ -59,16 +60,15 @@ void SensorImpl::initialize()
     // Get the looper associated with this thread
     looper = ALooper_forThread();
 
-    // Get the unique sensor manager
-    #if ANDROID_API >= 26 || __ANDROID_API__ >= 26
-        sensorManager = ASensorManager_getInstanceForPackage(nullptr);
-    #else
-        sensorManager = ASensorManager_getInstance();
-    #endif
+// Get the unique sensor manager
+#if ANDROID_API >= 26 || __ANDROID_API__ >= 26
+    sensorManager = ASensorManager_getInstanceForPackage(nullptr);
+#else
+    sensorManager = ASensorManager_getInstance();
+#endif
 
     // Create the sensor events queue and attach it to the looper
-    sensorEventQueue = ASensorManager_createEventQueue(sensorManager, looper,
-        1, &processSensorEvents, NULL);
+    sensorEventQueue = ASensorManager_createEventQueue(sensorManager, looper, 1, &processSensorEvents, nullptr);
 }
 
 
@@ -85,7 +85,7 @@ bool SensorImpl::isAvailable(Sensor::Type sensor)
 {
     const ASensor* available = getDefaultSensor(sensor);
 
-    return available? true : false;
+    return available != nullptr;
 }
 
 
@@ -99,14 +99,11 @@ bool SensorImpl::open(Sensor::Type sensor)
     if (!m_sensor)
         return false;
 
-    // Get the minimum delay allowed between events
-    Time minimumDelay = microseconds(ASensor_getMinDelay(m_sensor));
-
     // Set the event rate (not to consume too much battery)
-    ASensorEventQueue_setEventRate(sensorEventQueue, m_sensor, static_cast<Int32>(minimumDelay.asMicroseconds()));
+    ASensorEventQueue_setEventRate(sensorEventQueue, m_sensor, ASensor_getMinDelay(m_sensor));
 
-    // Save the index of the sensor
-    m_index = static_cast<unsigned int>(sensor);
+    // Save the type of the sensor
+    m_type = sensor;
 
     return true;
 }
@@ -120,13 +117,13 @@ void SensorImpl::close()
 
 
 ////////////////////////////////////////////////////////////
-Vector3f SensorImpl::update()
+Vector3f SensorImpl::update() const
 {
     // Update our sensor data list
-    while (ALooper_pollOnce(0, NULL, NULL, NULL) >= 0)
+    while (ALooper_pollOnce(0, nullptr, nullptr, nullptr) >= 0)
         ;
 
-    return sensorData[m_index];
+    return sensorData[m_type];
 }
 
 
@@ -141,14 +138,18 @@ void SensorImpl::setEnabled(bool enabled)
 
 
 ////////////////////////////////////////////////////////////
-ASensor const* SensorImpl::getDefaultSensor(Sensor::Type sensor)
+const ASensor* SensorImpl::getDefaultSensor(Sensor::Type sensor)
 {
     // Find the Android sensor type
-    static int types[] = {ASENSOR_TYPE_ACCELEROMETER, ASENSOR_TYPE_GYROSCOPE,
-        ASENSOR_TYPE_MAGNETIC_FIELD, ASENSOR_TYPE_GRAVITY, ASENSOR_TYPE_LINEAR_ACCELERATION,
-        ASENSOR_TYPE_ORIENTATION};
+    static constexpr EnumArray<Sensor::Type, int, Sensor::Count> types =
+        {ASENSOR_TYPE_ACCELEROMETER,
+         ASENSOR_TYPE_GYROSCOPE,
+         ASENSOR_TYPE_MAGNETIC_FIELD,
+         ASENSOR_TYPE_GRAVITY,
+         ASENSOR_TYPE_LINEAR_ACCELERATION,
+         ASENSOR_TYPE_ORIENTATION};
 
-    int type = types[sensor];
+    const int type = types[sensor];
 
     // Retrieve the default sensor matching this type
     return ASensorManager_getDefaultSensor(sensorManager, type);
@@ -162,48 +163,48 @@ int SensorImpl::processSensorEvents(int /* fd */, int /* events */, void* /* sen
 
     while (ASensorEventQueue_getEvents(sensorEventQueue, &event, 1) > 0)
     {
-        unsigned int type = Sensor::Count;
-        Vector3f data;
+        std::optional<Sensor::Type> type;
+        Vector3f                    data;
 
         switch (event.type)
         {
             case ASENSOR_TYPE_ACCELEROMETER:
-                type = Sensor::Accelerometer;
+                type   = Sensor::Type::Accelerometer;
                 data.x = event.acceleration.x;
                 data.y = event.acceleration.y;
                 data.z = event.acceleration.z;
                 break;
 
             case ASENSOR_TYPE_GYROSCOPE:
-                type = Sensor::Gyroscope;
+                type   = Sensor::Type::Gyroscope;
                 data.x = event.vector.x;
                 data.y = event.vector.y;
                 data.z = event.vector.z;
                 break;
 
             case ASENSOR_TYPE_MAGNETIC_FIELD:
-                type = Sensor::Magnetometer;
+                type   = Sensor::Type::Magnetometer;
                 data.x = event.magnetic.x;
                 data.y = event.magnetic.y;
                 data.z = event.magnetic.z;
                 break;
 
             case ASENSOR_TYPE_GRAVITY:
-                type = Sensor::Gravity;
+                type   = Sensor::Type::Gravity;
                 data.x = event.vector.x;
                 data.y = event.vector.y;
                 data.z = event.vector.z;
                 break;
 
             case ASENSOR_TYPE_LINEAR_ACCELERATION:
-                type = Sensor::UserAcceleration;
+                type   = Sensor::Type::UserAcceleration;
                 data.x = event.acceleration.x;
                 data.y = event.acceleration.y;
                 data.z = event.acceleration.z;
                 break;
 
             case ASENSOR_TYPE_ORIENTATION:
-                type = Sensor::Orientation;
+                type   = Sensor::Type::Orientation;
                 data.x = event.vector.x;
                 data.y = event.vector.y;
                 data.z = event.vector.z;
@@ -211,15 +212,13 @@ int SensorImpl::processSensorEvents(int /* fd */, int /* events */, void* /* sen
         }
 
         // An unknown sensor event has been detected, we don't know how to process it
-        if (type == Sensor::Count)
+        if (!type)
             continue;
 
-        sensorData[type] = data;
+        sensorData[*type] = data;
     }
 
     return 1;
 }
 
-} // namespace priv
-
-} // namespace sf
+} // namespace sf::priv
