@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,6 +27,7 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Clipboard.hpp>
 #include <SFML/Window/ClipboardImpl.hpp>
+
 #include <SFML/System/String.hpp>
 
 
@@ -42,7 +43,7 @@ String Clipboard::getString()
 ////////////////////////////////////////////////////////////
 void Clipboard::setString(const String& text)
 {
-    return priv::ClipboardImpl::setString(text);
+    priv::ClipboardImpl::setString(text);
 }
 
 } // namespace sf
