@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,8 +22,7 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_CURSORIMPL_HPP
-#define SFML_CURSORIMPL_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
@@ -31,20 +30,18 @@
 #include <SFML/Config.hpp>
 
 #if defined(SFML_SYSTEM_WINDOWS)
-    #include <SFML/Window/Win32/CursorImpl.hpp>
-#elif defined(SFML_SYSTEM_LINUX) || defined(SFML_SYSTEM_FREEBSD) || defined(SFML_SYSTEM_OPENBSD) || defined(SFML_SYSTEM_NETBSD)
-    #if defined(SFML_USE_DRM)
-        #include <SFML/Window/DRM/CursorImpl.hpp>
-    #else
-        #include <SFML/Window/Unix/CursorImpl.hpp>
-    #endif
+#include <SFML/Window/Win32/CursorImpl.hpp>
+#elif defined(SFML_SYSTEM_LINUX) || defined(SFML_SYSTEM_FREEBSD) || defined(SFML_SYSTEM_OPENBSD) || \
+    defined(SFML_SYSTEM_NETBSD)
+#if defined(SFML_USE_DRM)
+#include <SFML/Window/DRM/CursorImpl.hpp>
+#else
+#include <SFML/Window/Unix/CursorImpl.hpp>
+#endif
 #elif defined(SFML_SYSTEM_MACOS)
-    #include <SFML/Window/OSX/CursorImpl.hpp>
+#include <SFML/Window/macOS/CursorImpl.hpp>
 #elif defined(SFML_SYSTEM_IOS)
-    #include <SFML/Window/iOS/CursorImpl.hpp>
+#include <SFML/Window/iOS/CursorImpl.hpp>
 #elif defined(SFML_SYSTEM_ANDROID)
-    #include <SFML/Window/Android/CursorImpl.hpp>
+#include <SFML/Window/Android/CursorImpl.hpp>
 #endif
-
-
-#endif // SFML_CURSORIMPL_HPP
