@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -25,30 +25,31 @@
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
-#include <SFML/Window/GlResource.hpp>
 #include <SFML/Window/GlContext.hpp>
+#include <SFML/Window/GlResource.hpp>
+
+#include <utility>
 
 
 namespace sf
 {
 ////////////////////////////////////////////////////////////
-GlResource::GlResource()
+GlResource::GlResource() : m_sharedContext(priv::GlContext::getSharedContext())
 {
-    priv::GlContext::initResource();
 }
 
 
 ////////////////////////////////////////////////////////////
-GlResource::~GlResource()
+void GlResource::registerUnsharedGlObject(std::shared_ptr<void> object)
 {
-    priv::GlContext::cleanupResource();
+    priv::GlContext::registerUnsharedGlObject(std::move(object));
 }
 
 
 ////////////////////////////////////////////////////////////
-void GlResource::registerContextDestroyCallback(ContextDestroyCallback callback, void* arg)
+void GlResource::unregisterUnsharedGlObject(std::shared_ptr<void> object)
 {
-    priv::GlContext::registerContextDestroyCallback(callback, arg);
+    priv::GlContext::unregisterUnsharedGlObject(std::move(object));
 }
 
 
