@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,20 +22,19 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_JOYSTICKIMPL_HPP
-#define SFML_JOYSTICKIMPL_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Config.hpp>
+
 #include <SFML/Window/Joystick.hpp>
-#include <algorithm>
+
+#include <SFML/System/EnumArray.hpp>
 
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
 /// \brief Structure holding a joystick's information
@@ -43,14 +42,8 @@ namespace priv
 ////////////////////////////////////////////////////////////
 struct JoystickCaps
 {
-    JoystickCaps()
-    {
-        buttonCount = 0;
-        std::fill(axes, axes + Joystick::AxisCount, false);
-    }
-
-    unsigned int buttonCount;               //!< Number of buttons supported by the joystick
-    bool         axes[Joystick::AxisCount]; //!< Support for each axis
+    unsigned int                                         buttonCount{}; //!< Number of buttons supported by the joystick
+    EnumArray<Joystick::Axis, bool, Joystick::AxisCount> axes{};        //!< Support for each axis
 };
 
 
@@ -60,56 +53,44 @@ struct JoystickCaps
 ////////////////////////////////////////////////////////////
 struct JoystickState
 {
-    JoystickState()
-    {
-        connected = false;
-        std::fill(axes, axes + Joystick::AxisCount, 0.f);
-        std::fill(buttons, buttons + Joystick::ButtonCount, false);
-    }
-
-    bool  connected;                      //!< Is the joystick currently connected?
-    float axes[Joystick::AxisCount];      //!< Position of each axis, in range [-100, 100]
-    bool  buttons[Joystick::ButtonCount]; //!< Status of each button (true = pressed)
+    bool                                                  connected{}; //!< Is the joystick currently connected?
+    EnumArray<Joystick::Axis, float, Joystick::AxisCount> axes{};      //!< Position of each axis, in range [-100, 100]
+    std::array<bool, Joystick::ButtonCount>               buttons{};   //!< Status of each button (true = pressed)
 };
 
-} // namespace priv
-
-} // namespace sf
+} // namespace sf::priv
 
 
 #if defined(SFML_SYSTEM_WINDOWS)
 
-    #include <SFML/Window/Win32/JoystickImpl.hpp>
+#include <SFML/Window/Win32/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_LINUX)
 
-    #include <SFML/Window/Unix/JoystickImpl.hpp>
+#include <SFML/Window/Unix/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_FREEBSD)
 
-    #include <SFML/Window/FreeBSD/JoystickImpl.hpp>
+#include <SFML/Window/FreeBSD/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_OPENBSD)
 
-    #include <SFML/Window/OpenBSD/JoystickImpl.hpp>
+#include <SFML/Window/OpenBSD/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_NETBSD)
 
-    #include <SFML/Window/NetBSD/JoystickImpl.hpp>
+#include <SFML/Window/NetBSD/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_MACOS)
 
-    #include <SFML/Window/OSX/JoystickImpl.hpp>
+#include <SFML/Window/macOS/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_IOS)
 
-    #include <SFML/Window/iOS/JoystickImpl.hpp>
+#include <SFML/Window/iOS/JoystickImpl.hpp>
 
 #elif defined(SFML_SYSTEM_ANDROID)
 
-    #include <SFML/Window/Android/JoystickImpl.hpp>
+#include <SFML/Window/Android/JoystickImpl.hpp>
 
 #endif
-
-
-#endif // SFML_JOYSTICKIMPL_HPP
