@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -29,25 +29,25 @@
 #include <SFML/Window/SensorManager.hpp>
 
 
-namespace sf
+namespace sf::Sensor
 {
 
 ////////////////////////////////////////////////////////////
-bool Sensor::isAvailable(Type sensor)
+bool isAvailable(Type sensor)
 {
     return priv::SensorManager::getInstance().isAvailable(sensor);
 }
 
 ////////////////////////////////////////////////////////////
-void Sensor::setEnabled(Type sensor, bool enabled)
+void setEnabled(Type sensor, bool enabled)
 {
-    return priv::SensorManager::getInstance().setEnabled(sensor, enabled);
+    priv::SensorManager::getInstance().setEnabled(sensor, enabled);
 }
 
 ////////////////////////////////////////////////////////////
-Vector3f Sensor::getValue(Type sensor)
+Vector3f getValue(Type sensor)
 {
     return priv::SensorManager::getInstance().getValue(sensor);
 }
 
-} // namespace sf
+} // namespace sf::Sensor
