@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,38 +22,34 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_CURSORIMPLWIN32_HPP
-#define SFML_CURSORIMPLWIN32_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Cursor.hpp>
-#include <SFML/System/NonCopyable.hpp>
+
 #include <SFML/System/Vector2.hpp>
 
-#include <windows.h>
+#include <cstdint>
 
-namespace sf
-{
 
-namespace priv
+namespace sf::priv
 {
 ////////////////////////////////////////////////////////////
 /// \brief Win32 implementation of Cursor
 ///
 ////////////////////////////////////////////////////////////
-class CursorImpl : NonCopyable
+class CursorImpl
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Default constructor
     ///
     /// Refer to sf::Cursor::Cursor().
     ///
     ////////////////////////////////////////////////////////////
-    CursorImpl();
+    CursorImpl() = default;
 
     ////////////////////////////////////////////////////////////
     /// \brief Destructor
@@ -64,23 +60,34 @@ public:
     ~CursorImpl();
 
     ////////////////////////////////////////////////////////////
-    /// \brief Create a cursor with the provided image
-    ///
-    /// Refer to sf::Cursor::loadFromPixels().
+    /// \brief Deleted copy constructor
     ///
     ////////////////////////////////////////////////////////////
-    bool loadFromPixels(const Uint8* pixels, Vector2u size, Vector2u hotspot);
+    CursorImpl(const CursorImpl&) = delete;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Deleted copy assignment
+    ///
+    ////////////////////////////////////////////////////////////
+    CursorImpl& operator=(const CursorImpl&) = delete;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Create a cursor with the provided image
+    ///
+    /// Refer to sf::Cursor::createFromPixels().
+    ///
+    ////////////////////////////////////////////////////////////
+    bool loadFromPixels(const std::uint8_t* pixels, Vector2u size, Vector2u hotspot);
 
     ////////////////////////////////////////////////////////////
     /// \brief Create a native system cursor
     ///
-    /// Refer to sf::Cursor::loadFromSystem().
+    /// Refer to sf::Cursor::createFromSystem().
     ///
     ////////////////////////////////////////////////////////////
     bool loadFromSystem(Cursor::Type type);
 
 private:
-
     friend class WindowImplWin32;
 
     ////////////////////////////////////////////////////////////
@@ -92,13 +99,8 @@ private:
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    HCURSOR m_cursor;
-    bool m_systemCursor;
+    void* m_cursor{}; // Type erasure via `void*` is used here to avoid depending on `windows.h`
+    bool  m_systemCursor{};
 };
 
-} // namespace priv
-
-} // namespace sf
-
-#endif // SFML_CUSROSIMPLWIN32_HPP
-
+} // namespace sf::priv
