@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,46 +27,42 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/iOS/ClipboardImpl.hpp>
 
+#include <SFML/System/String.hpp>
+
 #import <UIKit/UIKit.h>
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 
 ////////////////////////////////////////////////////////////
 String ClipboardImpl::getString()
 {
-    UIPasteboard* pboard = [UIPasteboard generalPasteboard];
+    UIPasteboard* const pboard = [UIPasteboard generalPasteboard];
     if (pboard.hasStrings)
     {
-        NSString* data = pboard.string;
+        const NSString* const data = pboard.string;
 
-        char const* utf8 = [data cStringUsingEncoding:NSUTF8StringEncoding];
-        NSUInteger length = [data lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
+        const char*      utf8   = [data cStringUsingEncoding:NSUTF8StringEncoding];
+        const NSUInteger length = [data lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
 
         return String::fromUtf8(utf8, utf8 + length);
     }
-    else
-    {
-        return String();
-    }
+
+    return {};
 }
 
 
 ////////////////////////////////////////////////////////////
 void ClipboardImpl::setString(const String& text)
 {
-    std::basic_string<Uint8> utf8 = text.toUtf8();
-    NSString* data = [[NSString alloc] initWithBytes:utf8.data()
-                                              length:utf8.length()
-                                            encoding:NSUTF8StringEncoding];
+    const auto      utf8 = text.toUtf8();
+    NSString* const data = [[NSString alloc]
+        initWithBytes:utf8.data()
+               length:utf8.length()
+             encoding:NSUTF8StringEncoding];
 
-    UIPasteboard* pboard = [UIPasteboard generalPasteboard];
-    pboard.string = data;
+    UIPasteboard* const pboard = [UIPasteboard generalPasteboard];
+    pboard.string              = data;
 }
 
-} // namespace priv
-
-} // namespace sf
-
+} // namespace sf::priv
