@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,27 +27,10 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/iOS/CursorImpl.hpp>
 
-namespace sf
+namespace sf::priv
 {
-namespace priv
-{
-
 ////////////////////////////////////////////////////////////
-CursorImpl::CursorImpl()
-{
-    // Nothing.
-}
-
-
-////////////////////////////////////////////////////////////
-CursorImpl::~CursorImpl()
-{
-    // Nothing.
-}
-
-
-////////////////////////////////////////////////////////////
-bool CursorImpl::loadFromPixels(const Uint8* /* pixels */, Vector2u /* size */, Vector2u /* hotspot */)
+bool CursorImpl::loadFromPixels(const std::uint8_t* /* pixels */, Vector2u /* size */, Vector2u /* hotspot */)
 {
     // Not supported
     return false;
@@ -62,7 +45,4 @@ bool CursorImpl::loadFromSystem(Cursor::Type /* type */)
 }
 
 
-} // namespace priv
-
-} // namespace sf
-
+} // namespace sf::priv
