@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,25 +22,26 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_EAGLCONTEXT_HPP
-#define SFML_EAGLCONTEXT_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/GlContext.hpp>
 #include <SFML/Window/iOS/ObjCType.hpp>
-#include <SFML/System/Vector2.hpp>
+
 #include <SFML/System/Clock.hpp>
+#include <SFML/System/Vector2.hpp>
+
 #include <glad/gl.h>
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
 SFML_DECLARE_OBJC_CLASS(EAGLContext);
 SFML_DECLARE_OBJC_CLASS(SFView);
 
-namespace sf
-{
-namespace priv
+namespace sf::priv
 {
 class WindowImplUIKit;
 
@@ -51,11 +52,10 @@ class WindowImplUIKit;
 class EaglContext : public GlContext
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Create a new context, not associated to a window
     ///
-    /// \param shared Context to share the new one with (can be NULL)
+    /// \param shared Context to share the new one with (can be a null pointer)
     ///
     ////////////////////////////////////////////////////////////
     EaglContext(EaglContext* shared);
@@ -69,26 +69,23 @@ public:
     /// \param bitsPerPixel Pixel depth, in bits per pixel
     ///
     ////////////////////////////////////////////////////////////
-    EaglContext(EaglContext* shared, const ContextSettings& settings,
-                const WindowImpl* owner, unsigned int bitsPerPixel);
+    EaglContext(EaglContext* shared, const ContextSettings& settings, const WindowImpl& owner, unsigned int bitsPerPixel);
 
     ////////////////////////////////////////////////////////////
     /// \brief Create a new context that embeds its own rendering target
     ///
     /// \param shared   Context to share the new one with
     /// \param settings Creation parameters
-    /// \param width    Back buffer width, in pixels
-    /// \param height   Back buffer height, in pixels
+    /// \param size     Back buffer width and height, in pixels
     ///
     ////////////////////////////////////////////////////////////
-    EaglContext(EaglContext* shared, const ContextSettings& settings,
-                unsigned int width, unsigned int height);
+    EaglContext(EaglContext* shared, const ContextSettings& settings, Vector2u size);
 
     ////////////////////////////////////////////////////////////
     /// \brief Destructor
     ///
     ////////////////////////////////////////////////////////////
-    ~EaglContext();
+    ~EaglContext() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the address of an OpenGL function
@@ -115,7 +112,7 @@ public:
     /// \brief Display what has been rendered to the context so far
     ///
     ////////////////////////////////////////////////////////////
-    virtual void display();
+    void display() override;
 
     ////////////////////////////////////////////////////////////
     /// \brief Enable or disable vertical synchronization
@@ -125,53 +122,49 @@ public:
     /// This can avoid some visual artifacts, and limit the framerate
     /// to a good value (but not constant across different computers).
     ///
-    /// \param enabled: True to enable v-sync, false to deactivate
+    /// \param enabled: `true` to enable v-sync, `false` to deactivate
     ///
     ////////////////////////////////////////////////////////////
-    virtual void setVerticalSyncEnabled(bool enabled);
+    void setVerticalSyncEnabled(bool enabled) override;
 
 protected:
-
     ////////////////////////////////////////////////////////////
     /// \brief Activate the context as the current target
     ///        for rendering
     ///
     /// \param current Whether to make the context current or no longer current
     ///
-    /// \return True on success, false if any error happened
+    /// \return `true` on success, `false` if any error happened
     ///
     ////////////////////////////////////////////////////////////
-    virtual bool makeCurrent(bool current);
+    bool makeCurrent(bool current) override;
 
 private:
-
     ////////////////////////////////////////////////////////////
     /// \brief Create the context
     ///
-    /// \param shared       Context to share the new one with (can be NULL)
-    /// \param window       Window to attach the context to (can be NULL)
+    /// \param shared       Context to share the new one with (can be a null pointer)
+    /// \param window       Window to attach the context to
     /// \param bitsPerPixel Pixel depth, in bits per pixel
     /// \param settings     Creation parameters
     ///
     ////////////////////////////////////////////////////////////
-    void createContext(EaglContext* shared,
-                       const WindowImplUIKit* window,
-                       unsigned int bitsPerPixel,
+    void createContext(EaglContext*           shared,
+                       const WindowImplUIKit& window,
+                       unsigned int           bitsPerPixel,
                        const ContextSettings& settings);
 
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    EAGLContext* m_context; ///< The internal context
-    GLuint m_framebuffer;   ///< Frame buffer associated to the context
-    GLuint m_colorbuffer;   ///< Color render buffer
-    GLuint m_depthbuffer;   ///< Depth render buffer
-    bool m_vsyncEnabled;    ///< Vertical sync activation flag
-    Clock m_clock;          ///< Measures the elapsed time for the fake v-sync implementation
+    EAGLContext* m_context;        ///< The internal context
+    GLuint       m_framebuffer{};  ///< Frame buffer associated to the context
+    GLuint       m_colorbuffer{};  ///< Color render buffer
+    GLuint       m_depthbuffer{};  ///< Depth render buffer
+    bool         m_vsyncEnabled{}; ///< Vertical sync activation flag
+    Clock        m_clock;          ///< Measures the elapsed time for the fake v-sync implementation
 };
 
-} // namespace priv
+} // namespace sf::priv
 
-} // namespace sf
-
-#endif // SFML_EAGLCONTEXT_HPP
+#pragma GCC diagnostic pop
