@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2017 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,16 +22,12 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_OBJCTYPE_HPP
-#define SFML_OBJCTYPE_HPP
+#pragma once
 
 
 // Forward declare an Objective-C class
 #ifdef __OBJC__
-    #define SFML_DECLARE_OBJC_CLASS(c) @class c
+#define SFML_DECLARE_OBJC_CLASS(c) @class c
 #else
-    #define SFML_DECLARE_OBJC_CLASS(c) typedef struct objc_object c
+#define SFML_DECLARE_OBJC_CLASS(c) typedef struct objc_object c
 #endif
-
-
-#endif // SFML_OBJCTYPE_HPP
