@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -27,21 +27,23 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/iOS/SFAppDelegate.hpp>
 #include <SFML/Window/iOS/SFMain.hpp>
+
 #include <vector>
 
 
 namespace
 {
-    // Save the global instance of the delegate
-    SFAppDelegate* delegateInstance = NULL;
+// Save the global instance of the delegate
+SFAppDelegate* delegateInstance = nullptr;
 
-    // Current touches positions
-    std::vector<sf::Vector2i> touchPositions;
-}
+// Current touches positions
+std::vector<sf::Vector2i> touchPositions;
+} // namespace
 
 
-@interface SFAppDelegate()
+@interface SFAppDelegate ()
 
+// NOLINTNEXTLINE(readability-identifier-naming)
 @property (nonatomic) CMMotionManager* motionManager;
 
 @end
@@ -58,8 +60,8 @@ namespace
 {
     NSAssert(delegateInstance,
              @"SFAppDelegate instance is nil, this means SFML was not properly initialized. "
-             "Make sure that the file defining your main() function includes <SFML/Main.hpp>");
-    
+              "Make sure that the file defining your main() function includes <SFML/Main.hpp>");
+
     return delegateInstance;
 }
 
@@ -68,12 +70,12 @@ namespace
 - (void)runUserMain
 {
     // Arguments intentionally dropped, see comments in main in sfml-main
-    sfmlMain(0, NULL);
+    sfmlMain(0, nullptr);
 }
 
 
 ////////////////////////////////////////////////////////////
-- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
+- (BOOL)application:(UIApplication*)application didFinishLaunchingWithOptions:(NSDictionary*)launchOptions
 {
     // Save the delegate instance
     delegateInstance = self;
@@ -85,10 +87,14 @@ namespace
 
     // Register orientation changes notifications
     [[UIDevice currentDevice] beginGeneratingDeviceOrientationNotifications];
-    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(deviceOrientationDidChange:) name:UIDeviceOrientationDidChangeNotification object: nil];
+    [[NSNotificationCenter defaultCenter]
+        addObserver:self
+           selector:@selector(deviceOrientationDidChange:)
+               name:UIDeviceOrientationDidChangeNotification
+             object:nil];
 
     // Change the working directory to the resources directory
-    [[NSFileManager defaultManager] changeCurrentDirectoryPath: [[NSBundle mainBundle] resourcePath]];
+    [[NSFileManager defaultManager] changeCurrentDirectoryPath:[[NSBundle mainBundle] resourcePath]];
 
     // Schedule an indirect call to the user main, so that this call (and the whole
     // init sequence) can end, and the default splashscreen can be destroyed
@@ -100,70 +106,58 @@ namespace
 - (void)initBackingScale
 {
     id data = [[NSBundle mainBundle] objectForInfoDictionaryKey:@"NSHighResolutionCapable"];
-    if(data && [data boolValue])
+    if (data && [data boolValue])
         backingScaleFactor = [[UIScreen mainScreen] scale];
     else
         backingScaleFactor = 1;
 }
 
 ////////////////////////////////////////////////////////////
-- (void)applicationWillResignActive:(UIApplication *)application
+- (void)applicationWillResignActive:(UIApplication*)application
 {
     // Called when:
     // - the application is sent to background
     // - the application is interrupted by a call or message
 
-    // Generate a LostFocus event
+    // Generate a FocusLost event
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::LostFocus;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::FocusLost{});
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)applicationDidEnterBackground:(UIApplication *)application
+- (void)applicationDidEnterBackground:(UIApplication*)application
 {
     // Called when the application is sent to background (home button pressed)
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)applicationDidBecomeActive:(UIApplication *)application
+- (void)applicationDidBecomeActive:(UIApplication*)application
 {
     // Called when:
     // - the application is sent to foreground
     // - the application was interrupted by a call or message
 
-    // Generate a GainedFocus event
+    // Generate a FocusGained event
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::GainedFocus;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::FocusGained{});
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)applicationWillEnterForeground:(UIApplication *)application
+- (void)applicationWillEnterForeground:(UIApplication*)application
 {
     // Called when the application is sent to foreground (app icon pressed)
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)applicationWillTerminate:(UIApplication *)application
+- (void)applicationWillTerminate:(UIApplication*)application
 {
     // Generate a Closed event
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::Closed;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::Closed{});
 }
 
 - (bool)supportsOrientation:(UIDeviceOrientation)orientation
@@ -171,11 +165,18 @@ namespace
     if (!self.sfWindow)
         return false;
 
-    UIViewController* rootViewController = [((__bridge UIWindow*)(self.sfWindow->getSystemHandle())) rootViewController];
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
+
+    UIViewController* rootViewController = [((__bridge UIWindow*)(self.sfWindow->getNativeHandle())) rootViewController];
+
+#pragma GCC diagnostic pop
+
     if (!rootViewController || ![rootViewController shouldAutorotate])
         return false;
 
-    NSArray *supportedOrientations = [[NSBundle mainBundle] objectForInfoDictionaryKey:@"UISupportedInterfaceOrientations"];
+    NSArray* supportedOrientations = [[NSBundle mainBundle]
+        objectForInfoDictionaryKey:@"UISupportedInterfaceOrientations"];
     if (!supportedOrientations)
         return (1 << orientation) & [rootViewController supportedInterfaceOrientations];
 
@@ -189,18 +190,18 @@ namespace
     if ([supportedOrientations containsObject:@"UIInterfaceOrientationLandscapeRight"])
         appFlags += UIInterfaceOrientationMaskLandscapeRight;
 
-    return (1 << orientation) & [rootViewController supportedInterfaceOrientations] & appFlags;
+    return (1 << orientation) & [rootViewController supportedInterfaceOrientations] & static_cast<unsigned long>(appFlags);
 }
 
 - (bool)needsToFlipFrameForOrientation:(UIDeviceOrientation)orientation
 {
     sf::Vector2u size = self.sfWindow->getSize();
-    return ((!UIDeviceOrientationIsLandscape(orientation) && size.x > size.y)
-            || (UIDeviceOrientationIsLandscape(orientation) && size.y > size.x));
+    return (!UIDeviceOrientationIsLandscape(orientation) && size.x > size.y) ||
+           (UIDeviceOrientationIsLandscape(orientation) && size.y > size.x);
 }
 
 ////////////////////////////////////////////////////////////
-- (void)deviceOrientationDidChange:(NSNotification *)notification
+- (void)deviceOrientationDidChange:(NSNotification*)notification
 {
     if (self.sfWindow)
     {
@@ -216,11 +217,7 @@ namespace
                 std::swap(size.x, size.y);
 
             // Send a Resized event to the current window
-            sf::Event event;
-            event.type = sf::Event::Resized;
-            event.size.width = size.x;
-            event.size.height = size.y;
-            sfWindow->forwardEvent(event);
+            sfWindow->forwardEvent(sf::Event::Resized{size});
         }
     }
 }
@@ -238,17 +235,17 @@ namespace
 {
     if (index < touchPositions.size())
         return touchPositions[index];
-    else
-        return sf::Vector2i(-1, -1);
+
+    return sf::Vector2i(-1, -1);
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)notifyTouchBegin:(unsigned int)index atPosition:(sf::Vector2i)position;
+- (void)notifyTouchBegin:(unsigned int)index atPosition:(sf::Vector2i)position
 {
-    position.x *= backingScaleFactor;
-    position.y *= backingScaleFactor;
-    
+    position.x *= static_cast<int>(backingScaleFactor);
+    position.y *= static_cast<int>(backingScaleFactor);
+
     // save the touch position
     if (index >= touchPositions.size())
         touchPositions.resize(index + 1, sf::Vector2i(-1, -1));
@@ -256,23 +253,16 @@ namespace
 
     // notify the event to the application window
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::TouchBegan;
-        event.touch.finger = index;
-        event.touch.x = position.x;
-        event.touch.y = position.y;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::TouchBegan{index, position});
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)notifyTouchMove:(unsigned int)index atPosition:(sf::Vector2i)position;
+- (void)notifyTouchMove:(unsigned int)index atPosition:(sf::Vector2i)position
 {
-    position.x *= backingScaleFactor;
-    position.y *= backingScaleFactor;
-    
+    position.x *= static_cast<int>(backingScaleFactor);
+    position.y *= static_cast<int>(backingScaleFactor);
+
     // save the touch position
     if (index >= touchPositions.size())
         touchPositions.resize(index + 1, sf::Vector2i(-1, -1));
@@ -280,19 +270,12 @@ namespace
 
     // notify the event to the application window
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::TouchMoved;
-        event.touch.finger = index;
-        event.touch.x = position.x;
-        event.touch.y = position.y;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::TouchMoved{index, position});
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)notifyTouchEnd:(unsigned int)index atPosition:(sf::Vector2i)position;
+- (void)notifyTouchEnd:(unsigned int)index atPosition:(sf::Vector2i)position
 {
     // clear the touch position
     if (index < touchPositions.size())
@@ -300,27 +283,15 @@ namespace
 
     // notify the event to the application window
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::TouchEnded;
-        event.touch.finger = index;
-        event.touch.x = position.x * backingScaleFactor;
-        event.touch.y = position.y * backingScaleFactor;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::TouchEnded{index, position * static_cast<int>(backingScaleFactor)});
 }
 
 
 ////////////////////////////////////////////////////////////
-- (void)notifyCharacter:(sf::Uint32)character
+- (void)notifyCharacter:(char32_t)character
 {
     if (self.sfWindow)
-    {
-        sf::Event event;
-        event.type = sf::Event::TextEntered;
-        event.text.unicode = character;
-        sfWindow->forwardEvent(event);
-    }
+        sfWindow->forwardEvent(sf::Event::TextEntered{character});
 }
 
 
